/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.springlayout.util;

import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Locale;

import org.springframework.util.StringUtils;
/**
 * Created on 14/11/2006
 *
 * @author Rob Monie
 */
public class DateFormatUtil
{

   /**
    * Gets a localised date format with a four digit year with month day and year separated by "/" character.
    * 
    * Essentially it just swaps between dd/MM/yyyy or MM/dd/yyyy depending on the locale.
    * 
    * @param locale
    * @return a localised date format with a four digit year.
    */
   public static SimpleDateFormat getLocalizedDateFormat(Locale locale)
   {
      SimpleDateFormat dateFormat = (SimpleDateFormat) DateFormat.getDateInstance(DateFormat.SHORT, locale);
      
      //not certain which locales give d or dd, M or MM so strip back to single char to start with
      String shortDateFormat = StringUtils.replace(StringUtils.replace(dateFormat.toLocalizedPattern(),"MM","M"),"dd","d");
      
      String fullDateFormat = StringUtils.replace(StringUtils.replace(StringUtils.replace(shortDateFormat, "yy", "yyyy"), "d","dd"),"M","MM");
      
      dateFormat.applyLocalizedPattern(fullDateFormat);
      
      return dateFormat;
   }
   
   /**
    * Gets a localised date format for the dynarch js calendar picker
    * 
    * 
    * @param locale
    * @return a localised date format with a four digit year.
    */
   public static String getLocalizedDateFormatForJsPicker(Locale locale)
   {
      SimpleDateFormat dateFormat = (SimpleDateFormat) DateFormat.getDateInstance(DateFormat.SHORT, locale);
      
      //not certain which locales give d or dd, M or MM so strip back to single char to start with
      String shortDateFormat = StringUtils.replace(StringUtils.replace(dateFormat.toLocalizedPattern(),"MM","M"),"dd","d");

      String fullDateFormat = StringUtils.replace(StringUtils.replace(StringUtils.replace(shortDateFormat, "yy", "%Y"), "d","%d"),"M","%m");
      
      return fullDateFormat;
   }
   
}
