/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sf.springlayout.util;

import java.io.FileWriter;
import java.io.IOException;
import java.io.InputStream;
import java.io.PrintWriter;
import java.net.URL;
import java.util.ArrayList;
import java.util.Enumeration;
import java.util.Properties;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * Singleton wrapper for the application's properties file
 * @author Adam Boas
 * Created on Jun 20, 2005
 */
public class SpringLayoutConfiguration
{
   private static final Log log = LogFactory.getLog(SpringLayoutConfiguration.class);
   private static SpringLayoutConfiguration instance;
   private final String PROPERTIES_NAME = "springLayoutConfig.properties";
   private final Properties props = new Properties();
   
   private SpringLayoutConfiguration()
   {
      InputStream is = null;
      try
      {
         is = this.getClass().getClassLoader().getResourceAsStream(PROPERTIES_NAME);
         if(is != null)
         {
            this.props.load(is);
         }
      }
      catch (Exception e)
      {
         //e.printStackTrace(System.err);
      }
      finally
      {
         if (null != is)
         {
            try
            {
               is.close();
            }
            catch (Throwable t)
            {
               log.warn("Unable to close Input Stream for " + this.PROPERTIES_NAME);
               // Can't do anything here
            }
         }
      }
   }
   
   /**
    * @return this SpringLayoutConfiguration object
    */
   public static SpringLayoutConfiguration getInstance()
   {
      if(instance == null)
         instance = new SpringLayoutConfiguration();
      return instance;
   }
   
   /**
    * Gets the property held by the current properties object associated with the given
    * key 
    * @param key
    * @return property value associated with the given key
    */
   public String getProperty(String key)
   {
      return props.getProperty(key);
   }
   
   
   /**
    * Adds a key value pair to the current properties object used by this config object
    * @param key
    * @param value
    */
   public void setProperty(String key, String value)
   {
      this.props.setProperty(key, value);
   }
   
   
   /**
    * Writes a key value pair to the current properties file
    * @param key
    * @param value
    * @throws IOException
    */
   public void writeProperty(String key, String value) throws IOException
   {
      URL configURL = this.getClass().getClassLoader().getResource(PROPERTIES_NAME);
      PrintWriter pw = new PrintWriter(new FileWriter(configURL.getFile(), true));
      pw.println(key + "=" + value);
      pw.close();
   }
   
   /**
    * @return all properties in this configurations's properties file
    */
   public String[] getProperties()
   {
      Enumeration e = props.propertyNames();
      ArrayList list = new ArrayList();
      while(e.hasMoreElements())
         list.add(e.nextElement());
      return (String[])list.toArray(new String[list.size()]);
   }

}
