/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sf.springlayout.web.bind;

import org.springframework.beans.MutablePropertyValues;
import org.springframework.beans.PropertyValue;
import org.springframework.web.bind.ServletRequestDataBinder;

/**
 * Temporary replacement for the core Spring <code>ServletRequestDataBinder</code>.  
 * Fixes a bug in Spring that has apparently been fixed in Spring 2.01 and 1.29.
 * @author Rob Monie
 * 
 */
public class LayoutServletRequestDataBinder extends ServletRequestDataBinder
{

   public LayoutServletRequestDataBinder(Object target)
   {
      super(target);
   }

   public LayoutServletRequestDataBinder(Object target, String objectName)
   {
      super(target, objectName);
   }

   /**
    * Overriden to remove any fieldMarkerPrefix prefixed fields from mpvs thus
    * preventing exceptions on these fields when attempting to resolve their
    * values against the command object
    * 
    * @param mpvs
    *           the property values to be bound (can be modified)
    * @see #getFieldMarkerPrefix
    * @see #getEmptyValue(String, Class)
    */
   protected void checkFieldMarkers(MutablePropertyValues mpvs)
   {

      super.checkFieldMarkers(mpvs);

      // now remove all properties with the fieldMarkerPrefix
      //done as a second iteration to preserve Spring 2.x / 1.x compatability
      if (getFieldMarkerPrefix() != null)
      {
         String fieldMarkerPrefix = getFieldMarkerPrefix();
         PropertyValue[] pvArray = mpvs.getPropertyValues();
         for (int i = 0; i < pvArray.length; i++)
         {
            PropertyValue pv = pvArray[i];
            if (pv.getName().startsWith(fieldMarkerPrefix))
            {
               mpvs.removePropertyValue(pv.getName());
            }
         }
      }
   }

}
