/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sf.springlayout.web.controller;

import java.util.Locale;

import javax.servlet.http.HttpServletRequest;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.beans.factory.InitializingBean;
import org.springframework.context.NoSuchMessageException;
import org.springframework.web.servlet.mvc.AbstractController;
import org.springframework.web.servlet.support.RequestContextUtils;

/**
 * Base controller for non form based controllers. 
 * @author Rob Monie
 * 
*/
public abstract class AbstractBaseController extends AbstractController implements InitializingBean
{

   protected static Log log = LogFactory.getLog(AbstractBaseController.class);
   


   public AbstractBaseController()
   {
      super();
      this.setCacheSeconds(0);
   }

   /**
    * Gets a message from the resource bundle based on the current locale and key / arguments passed.
    * @param code the key to the message
    * @param args arguments to be parsed with the message
    * @param request current request
    * @return a localised message
    * @throws NoSuchMessageException
    */
   protected String getMessage(String code, Object[] args, HttpServletRequest request) throws NoSuchMessageException
   {
      Locale locale = RequestContextUtils.getLocale(request);
      return this.getMessageSourceAccessor().getMessage(code, args, locale);
   }
   
   /**
    * Gets a message from the resource bundle based on the current locale and key passed.
    * @param code the key to the message
    * @param request current request
    * @return a localised message
    * @throws NoSuchMessageException
    */
   protected String getMessage(String code, HttpServletRequest request) throws NoSuchMessageException
   {
      Locale locale = RequestContextUtils.getLocale(request);
      return this.getMessageSourceAccessor().getMessage(code, locale);
   }

   /* (non-Javadoc)
    * @see org.springframework.beans.factory.InitializingBean#afterPropertiesSet()
    */
   public void afterPropertiesSet() throws Exception
   {
      
   }

   
}
