/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sf.springlayout.web.controller.propertyeditor;

import java.beans.PropertyEditorSupport;

import org.springframework.util.StringUtils;

/**
 * A property editor that handles decimal round numbers.
 */
public final class NullableDecimalPropertyEditor extends
      PropertyEditorSupport
{
   private Converter converter;
   
   public NullableDecimalPropertyEditor(Converter converter)
   {
      this.converter = converter;
   }
   
   public static final Converter BYTE_CONVERTER = new Converter()
   {
      public Object stringToNumber(String str)
      {
         return Byte.valueOf(str);
      }
   };
   public static final Converter SHORT_CONVERTER = new Converter()
   {
      public Object stringToNumber(String str)
      {
         return Short.valueOf(str);
      }
   };
   public static final Converter INTEGER_CONVERTER = new Converter()
   {
      public Object stringToNumber(String str)
      {
         return Integer.valueOf(str);
      }
   };
   public static final Converter LONG_CONVERTER = new Converter()
   {
      public Object stringToNumber(String str)
      {
         return Long.valueOf(str);
      }
   };
   
   public void setAsText(String text) throws IllegalArgumentException {
      if (!StringUtils.hasText(text)) {
         setValue(null);
      }
      else {
         setValue(this.converter.stringToNumber(text));
      }
   }
   
   public String getAsText() {
      Object value = getValue();
      if (value == null) {
         return "";
      }
      
      return value.toString();
   }

   private interface Converter
   {
      public Object stringToNumber(String str);
   }
}
