/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.springlayout.web.controller.propertyeditor;


import java.beans.PropertyEditorSupport;

import org.springframework.util.StringUtils;


/**
 * A generic PropertyEditor for the referenceDataManager uses Invocation to <code>invoke</code> the method supplied. 
 * @author beerj
 * 
 */
public class ZeroPaddedNumberPropertyEditor extends PropertyEditorSupport
{
   private final int totalLength;

   public ZeroPaddedNumberPropertyEditor(int totalLength) throws IllegalArgumentException 
   { 
      this.totalLength = totalLength;
   }

   /**
    * Parse the Number from the given text, using the specified NumberFormat.
    */
   public void setAsText(String text) throws IllegalArgumentException {
      if (!StringUtils.hasText(text)) {
         // Treat empty String as null value.
         setValue(null);
      }
      else {
         // Use default valueOf methods for parsing text.
         setValue(new Integer(Integer.parseInt(text, 10)));
      }
   }

   /**
    * Format the Number as String, using the specified NumberFormat.
    */
   public String getAsText() {
      Object value = getValue();
      if (value == null) {
         return "";
      }
      else {
         // Use toString method for rendering value - append leading zeros with a buffer
         String valueStr = value.toString();
         if(valueStr.length() >= this.totalLength)
            return valueStr;
         
         StringBuffer sb = new StringBuffer();
         for(int ii = 1; ii < totalLength; ii++)
         {
            sb.append("0");
         }        
         sb.append(valueStr);
         return sb.toString();
      }
   }
}
