/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.springlayout.web.interceptor;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import net.sf.springlayout.web.util.WebConstants;

import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.handler.HandlerInterceptorAdapter;


/**
 * Moves messages placed in the session into the request scope and removes session attributes on next request.
 * This enables messages to survive a rediect following a form submission but ensures that they are only displayed once. 
 * @author Rob Monie
*/
public class MessagesInterceptor extends HandlerInterceptorAdapter {

   
   /* (non-Javadoc)
    * @see org.springframework.web.servlet.HandlerInterceptor#preHandle(javax.servlet.http.HttpServletRequest, javax.servlet.http.HttpServletResponse, java.lang.Object)
    */
   public boolean preHandle(HttpServletRequest request,
                 HttpServletResponse response,
                 Object handler)
    throws Exception {
    
      //move messages from the session to the request and cleanup the session
     if (request.getSession().getAttribute(WebConstants.MESSAGES) != null) {
        request.setAttribute(WebConstants.MESSAGES, request.getSession().getAttribute(WebConstants.MESSAGES));
        request.getSession().removeAttribute(WebConstants.MESSAGES);
     }
     
     return true;
   }    

   /* (non-Javadoc)
    * @see org.springframework.web.servlet.HandlerInterceptor#postHandle(javax.servlet.http.HttpServletRequest, javax.servlet.http.HttpServletResponse, java.lang.Object, org.springframework.web.servlet.ModelAndView)
    */
   public void postHandle(HttpServletRequest request,
               HttpServletResponse response,
               Object handler,
               ModelAndView modelAndView)
    throws Exception {
    
      //move messages from the session to the request.
     if (request.getSession().getAttribute(WebConstants.MESSAGES) != null) {
        request.setAttribute(WebConstants.MESSAGES, request.getSession().getAttribute(WebConstants.MESSAGES));
     }

   }

 }