/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.springlayout.web.interceptor;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import net.sf.springlayout.web.util.WebConstants;

import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.handler.HandlerInterceptorAdapter;


/**
 * Checks an incoming request for the <code>WebConstants.SCREEN_POSITION_PARAM</code> 
 * parameter and passes to the next request via the session and sets as a request attribute 
 * in order to survive a redirect.  The <code>WebConstants.SCREEN_POSITION_PARAM</code> is 
 * set by the ui when a postback is submitted to pass the current screen position to the resulting screen
 * so it can be reopened in the same position.
 * @author Rob Monie
*/
public class ScreenPositionInterceptor extends HandlerInterceptorAdapter {

   
   /* (non-Javadoc)
    * @see org.springframework.web.servlet.HandlerInterceptor#preHandle(javax.servlet.http.HttpServletRequest, javax.servlet.http.HttpServletResponse, java.lang.Object)
    */
   public boolean preHandle(HttpServletRequest request,
                 HttpServletResponse response,
                 Object handler)
    throws Exception {
    
      //    move screen position attribute from the session to the request and clean up the session
    if(request.getSession().getAttribute(WebConstants.SCREEN_POSITION_PARAM) != null) {
       request.setAttribute(WebConstants.SCREEN_POSITION_PARAM, request.getSession().getAttribute(WebConstants.SCREEN_POSITION_PARAM));
       request.getSession().removeAttribute(WebConstants.SCREEN_POSITION_PARAM);
    }

    
     return true;
   }    

   /* (non-Javadoc)
    * @see org.springframework.web.servlet.HandlerInterceptor#postHandle(javax.servlet.http.HttpServletRequest, javax.servlet.http.HttpServletResponse, java.lang.Object, org.springframework.web.servlet.ModelAndView)
    */
   public void postHandle(HttpServletRequest request,
               HttpServletResponse response,
               Object handler,
               ModelAndView modelAndView)
    throws Exception {
    

     //   move screen position attribute from the request to the session
     if (request.getParameter(WebConstants.SCREEN_POSITION_PARAM) != null) {
        request.getSession().setAttribute(WebConstants.SCREEN_POSITION_PARAM, request.getParameter(WebConstants.SCREEN_POSITION_PARAM));
     }
     
     
     
   }

 }