/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.springlayout.web.layout;

import java.util.List;

import javax.servlet.http.HttpServletRequest;

import net.sf.springlayout.web.validator.NestedPathResolver;
import net.sf.springlayout.web.validator.condition.Condition;

import org.springframework.beans.BeanWrapper;
import org.springframework.validation.Errors;


/**
 * Defines a field used in the UI that is mapped to a property of the command object.  
 * @author Rob Monie, Adam Boas
 * 
*/
public interface FieldDefinition
{


   /**
    * Calls validate on all validation rules associated with this fieldDefinition.
    * @param request the current request
    * @param resolver nestedPath resolver for the current object
    * @param wrapper a bean wrapper for the current object
    * @param errors the current errors object
    */
   public void validate(HttpServletRequest request, 
         NestedPathResolver resolver, 
         BeanWrapper wrapper,
         Errors errors);

   /**
    * @return Returns the fieldKey.
    */
   public String getFieldKey();
   /**
    * @param fieldKey The fieldKey to set.
    */
   public void setFieldKey(String fieldKey);
   /**
    * @return if the field is currently mandatory.
    */
   public boolean isMandatory();
   
   /**
    * @param mandatory The mandatory to set.
    */
   public void setMandatory(boolean mandatory);
   
   /**
    * @param mandatoryCondition, sets a single mandatory condition.
    */
   public void setMandatoryCondition(Condition mandatoryCondition);
   
   
   /**
    * Retrieves all mandatory conditions which this Field definition contains.
    * @return mandatory condition which this Field definition contains.
    */
   public Condition getMandatoryCondition();
   
   /**
    * @return Returns the validationRules.
    */
   public List getValidationRules();
   
   /**
    * @param validationRules The validationRules to set.
    */
   public void setValidationRules(List validationRules);
      
   /**
    * Retrieves the alternateFieldKeysForError for this LayoutFieldDefinition.
    * @return Returns the alternateFieldKeysForError for this LayoutFieldDefinition.
    */
   public void setAlternateFieldKeysForError(List alternateFieldKeysForError);
   
   /**
    *Gets the alternateFieldKeysForError for this LayoutFieldDefinition.
    * @param alternateFieldKeysForError 
    */
   public List getAlternateFieldKeysForError();
   
  

   /**
    * looks inside validation rules and returns maxLength if such a validation rule is defined
    * @return
    */
   public int getMaxLength();
   
}
