/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.springlayout.web.layout;

import java.util.Map;

import javax.servlet.http.HttpServletRequest;

import org.springframework.validation.Errors;


/**
 * Defines a single panel on a muli-panel page.  
 * @author Rob Monie
 * 
*/

public interface Form
{
   /**
    * @return Returns the fields.
    */
   public Map getFieldDefinitions();
   
   /**
    * @param fields The fields to set.
    */
   
   public void setFieldDefinitions(Map fields);
   
   /**
    * Gets a field definition from the fieldDefinitions map by the field path passed in.
    * Indexed fields with paths that traverse collections such as commandObject.list[2].fieldName
    *  match against a non-indexed key in a format such as commandObject.list.fieldName. This way single 
    *  field definition is used for all elements within a collection resulting in a fully dynamic solution.
    * @param path the path of the property in the object graph
    * @return a field definition for the path
    */
   public FieldDefinition getFieldDefinition(String path);
   
    
   /**
    * Calls validate on all validation rules associated with the fieldDefinitions for this panel.
    * 
    * @param request the current HttpServletRequest
    * @param obj the current command object to be validated
    * @param errors the current errors for this request
    */
   public void validate(HttpServletRequest request, Object obj, Errors errors);

   /**
    * Gets errors for the current panel by retrieving all errors relating to fields 
    * defined for this panel from the errors object.
    * @param errors the current page errors
    * @return a map of errors for this panel
    */
   public Map getErrors(Errors errors);
   
   /**
    * Checks the current panel for errors
    * 
    * @param errors the current page errors
    * @return true if errors present for this panel group
    */
   public boolean hasErrors(Errors errors);
   
   /**
    * @return Returns the formName.
    */
   public String getFormName();
   
   /**
    * @param panelName The panelName to set.
    */
   public void setFormName(String panelFormName);
   
   
   /**
    * Gets the url for this panel
    * @return
    */
   public String getFormAction();

   /**
    * Sets the url for this panel.  The url should match that used to map to the controller used by this panel.
    * @param url
    */
   public void setFormAction(String url);
   
   /**
    * Retrieves the controllerBeanName for this LayoutForm.
    * @return Returns the controllerBeanName for this LayoutForm.
    */
   public String getControllerBeanName();
   
   /**
    *Sets the controllerBeanName for this LayoutForm.
    * @param controllerBeanName Sets the controllerBeanName for this LayoutForm.
    */
   public void setControllerBeanName(String controllerBeanName);

}
