/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.springlayout.web.layout;

import java.util.Map;

import javax.servlet.http.HttpServletRequest;

/**
 * Default implementation of a PanelForm
 * @author Rob Monie
 * 
 */
public class LayoutPanelForm extends LayoutForm  implements PanelForm,  Comparable
{
   private String redirectFormViewName;
   private int index;
   private PanelFormTabStateManager panelFormTabStateManager;
   private String panelLabel;
   
   

   /* (non-Javadoc)
    * @see net.sf.springlayout.web.panel.IPanel#setIndex(int)
    */
   public void setIndex(int index)
   {
      this.index = index;
   }
   
   

   /* (non-Javadoc)
    * @see net.sf.springlayout.web.layout.PanelForm#isDisabled(javax.servlet.http.HttpServletRequest)
    */
   public boolean isDisabled(HttpServletRequest request)
   {
     if(panelFormTabStateManager == null)
        return false;
   
     if (panelFormTabStateManager.isDisabled(request))
        return true;
     else
        return false;
   }



   /* (non-Javadoc)
    * @see net.sf.springlayout.web.panel.IPanel#getIndex()
    */
   public int getIndex()
   {
      return index;
   }


   /*
    * (non-Javadoc)
    * 
    * @see net.sf.springlayout.web.layout.PanelForm#setDisabledPanelManager(net.sf.springlayout.web.layout.IDisabledPanelManager)
    */
   public void setPanelFormTabStateManager(
           PanelFormTabStateManager panelFormTabStateManager) 
   {
       this.panelFormTabStateManager = panelFormTabStateManager;

   }

   
   /**
    * Compares panels by their index
    * 
    * @see java.lang.Comparable#compareTo(java.lang.Object)
    */
   public int compareTo(Object arg0)
   {
      
      LayoutPanelForm that = (LayoutPanelForm) arg0;
      
      if ( this == that) return 0;
      
      if(this.index < that.getIndex()) return -1;
      
      if(this.index > that.getIndex()) return 1;
      
      return 0;

   }
   
   /**
    * Over-ridden to depend soley on the panelName
    * @see java.lang.Object#equals(java.lang.Object)
    */
   public boolean equals(Object obj)
   {
      if(!(obj instanceof LayoutPanelForm))
         return false;
      LayoutPanelForm otherPanel = (LayoutPanelForm)obj;
      return this.panelLabel.equals(otherPanel.getPanelLabel());
   }

   /** 
    * Over-ridden to conform to equals and depend soley on the panelName
    * @see java.lang.Object#hashCode()
    */
   public int hashCode()
   {
      return this.panelLabel.hashCode();
   }
   

   /* (non-Javadoc)
    * @see net.sf.springlayout.web.layout.PanelForm#getRedirectFormViewName()
    */
   public String getRedirectFormViewName()
   {
      return redirectFormViewName;
   }

   /* (non-Javadoc)
    * @see net.sf.springlayout.web.layout.PanelForm#setRedirectFormViewName(java.lang.String)
    */
   public void setRedirectFormViewName(String redirectFormViewName)
   {
      this.redirectFormViewName = redirectFormViewName;
   }

   /* (non-Javadoc)
    * @see net.sf.springlayout.web.layout.PanelForm#getPanelLabel()
    */
   public String getPanelLabel()
   {
      return panelLabel;
   }

   /* (non-Javadoc)
    * @see net.sf.springlayout.web.layout.PanelForm#setPanelLabel(java.lang.String)
    */
   public void setPanelLabel(String panelLabel)
   {
      this.panelLabel = panelLabel;
   }
   

   
}
