/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.springlayout.web.layout;

import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;

import net.sf.springlayout.web.controller.FormController;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.context.WebApplicationContext;
import org.springframework.web.servlet.support.RequestContextUtils;


/**
 * Default implementation of a PanelFormGroup
 * @author Rob Monie
 * 
*/
public class LayoutPanelFormGroup implements PanelFormGroup
{

   private static Log log = LogFactory.getLog(LayoutPanelFormGroup.class);

   private List panelForms;

   public List getPanelForms()
   {
      return panelForms;
   }

   /*
    * (non-Javadoc)
    * 
    * @see net.sf.springlayout.web.panel.IPanelGroup#setPanels(java.util.List)
    */
   public void setPanelForms(List panelForms)
   {
      this.panelForms = panelForms;
   }

   /*
    * (non-Javadoc)
    * 
    * @see net.sf.springlayout.web.layout.PanelFormGroup#getPanelByName(java.lang.String)
    */
   public PanelForm getPanelFormByLabel(String panelFormLabel)
   {
      for (Iterator it = panelForms.iterator(); it.hasNext();)
      {
         PanelForm panelForm = (PanelForm) it.next();
         if (panelForm.getPanelLabel().equals(panelFormLabel))
         {
            return panelForm;
         }
      }
      return null;
   }

   /*
    * @see net.sf.springlayout.web.panel.IPanelGroup#validate(javax.servlet.http.HttpServletRequest,
    *      java.lang.Object, org.springframework.validation.Errors)
    */
   public void validate(HttpServletRequest request, Object obj, Errors errors)
   {

      log.debug("Validating panel group");

      if (this.panelForms != null)
      {
         WebApplicationContext ctx = RequestContextUtils
               .getWebApplicationContext(request);
         for (Iterator it = panelForms.iterator(); it.hasNext();)
         {
            PanelForm panelForm = (PanelForm) it.next();
            String controllerName = panelForm.getControllerBeanName();
            if(controllerName != null)
            {
               FormController controller = (FormController) ctx
                     .getBean(controllerName);
               Object objectToValidate = controller.getCommandObject(request);
   
               
               if (!objectToValidate.getClass().getName().equals(
                     ((BindException) errors).getTarget().getClass().getName()))
               {
                  Errors tmpErrors = new BindException(objectToValidate, errors.getObjectName());
                  panelForm.validate(request, objectToValidate, tmpErrors);
                  errors.addAllErrors(tmpErrors);
               }
               else
               {
                  panelForm.validate(request, objectToValidate, errors);
               }
            }
         }
      }
   }

   /*
    * (non-Javadoc)
    * 
    * @see net.sf.springlayout.web.layout.PanelFormGroup#hasErrors(org.springframework.validation.Errors)
    */
   public boolean hasErrors(Errors errors)
   {
      if (getErrors(errors).isEmpty())
      {
         log.debug("LayoutPanelForm group free of validation errors");
         return false;
      }
      else
      {
         log.debug("LayoutPanelForm group has errors");
         return true;
      }
   }

   /*
    * (non-Javadoc)
    * 
    * @see net.sf.springlayout.web.layout.PanelFormGroup#getErrors(org.springframework.validation.Errors)
    */
   public Map getErrors(Errors errors)
   {
      Map panelFormGroupErrors = new HashMap();

      if (panelForms != null)
      {
         for (Iterator it = panelForms.iterator(); it.hasNext();)
         {
            PanelForm panelForm = (PanelForm) it.next();
            panelFormGroupErrors.putAll(panelForm.getErrors(errors));
         }
      }

      log.debug("LayoutPanelForm group found to have "
            + panelFormGroupErrors.size() + " errors");
      return panelFormGroupErrors;

   }

   /*
    * (non-Javadoc)
    * 
    * @see net.sf.springlayout.web.layout.PanelFormGroup#getErrorsForPanel(org.springframework.validation.Errors,
    *      int)
    */
   public Map getErrorsForPanelForm(Errors errors, int panelFormIndex)
   {
      Map panelFormErrors = new HashMap();

      if (panelForms != null)
      {
         PanelForm panelForm = (PanelForm) panelForms.get(panelFormIndex);
         if (panelForm != null)
         {
            panelFormErrors.putAll(panelForm.getErrors(errors));
         }
      }

      log.debug("LayoutPanelForm with index " + panelFormIndex
            + " found to have " + panelFormErrors.size() + " errors");

      return panelFormErrors;
   }

   // /* (non-Javadoc)
   // * @see
   // net.sf.springlayout.web.layout.PanelFormGroup#isEditMode(javax.servlet.http.HttpServletRequest)
   // */
   // public boolean isEditMode(HttpServletRequest request)
   // {
   // return RequestUtilSupport.isEditMode(request);
   // }
   //   
   // /*
   // * (non-Javadoc)
   // *
   // * @see
   // net.sf.springlayout.web.panel.IPanelGroup#getReadOnly(javax.servlet.http.HttpServletRequest)
   // */
   // public boolean isReadOnly(HttpServletRequest request)
   // {
   //
   // return ! RequestUtilSupport.isEditMode(request);
   //
   // }

}
