/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.springlayout.web.layout;

import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;

import org.springframework.validation.Errors;

/**
 * Holds multiple <code>PanelForm</code> objects for a multi-panel page.
 * @author Rob Monie
 * 
*/
public interface PanelFormGroup
{
   
   
   /**
    * @return Returns the panelFormForms.
    */
   public List getPanelForms();

   /**
    * @param panelFormForms The panelFormForms to set.
    */
   public void setPanelForms(List panelFormForms);
   
   /**
    * Gets a panelFormForm from the panelFormFormGroup by name
    * @param formName
    * @return a panelForm
    */
   public PanelForm getPanelFormByLabel(String panelFormName);
   
   
   /**
    * Calls validate on all validation rules associated with the fieldDefinitions for all panelForms in this panelForm group.
    * 
    * @param request the current HttpServletRequest
    * @param obj the current command object to be validated
    * @param errors the current errors for this request
    */
   public void validate(HttpServletRequest request, Object obj, Errors errors);


   /**
    * Checks all panelForms for errors
    * 
    * @param errors the current page errors
    * @return true if errors present for this panelForm group
    */
   public boolean hasErrors(Errors errors);
   
   /**
    * Gets all errors for the panelForm group, returned as a map based on the field key
    * 
    * @param errors the current page errorst
    * @return map of all errors for the panelForm group
    */
   public Map getErrors(Errors errors);
   
   /**
    * Returns the errors for the panelForm by it's index
    * 
    * @param errors the current page errors
    * @param panelFormIndex the index of the panelForm to get errors for
    * @return errors for the requested panelForm
    */
   public Map getErrorsForPanelForm(Errors errors, int panelFormIndex);
   
//   /**
//    * Returns whether the current page is readOnly or not based on the edit parameter passed in the url
//    * 
//    * @param request the current HttpServletRequest
//    * @return is this page readOnly
//    */
//   public boolean isReadOnly(HttpServletRequest request);
//   
//   /**
//    * Returns whether the current page is in edit mode or not based on the edit parameter passed in the url
//    * @param request
//    * @return is this page in edit mode
//    */
//   public boolean isEditMode(HttpServletRequest request);
}
