/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.springlayout.web.layout.servlet;

import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.util.StringUtils;


/**
 * Handles serving up of files in the SpringLayout layoutResources including js,
 * css, htm and image files.  Simplified version of DWR Servlet.
 * 
 * @author Rob Monie
 * 
 */
public class LayoutResourcesServlet extends HttpServlet
{

   private static Log log = LogFactory.getLog(LayoutResourcesServlet.class);

   /**
    * Path to the root of the web app
    */
   static final String PATH_ROOT = "/";

   private FileProcessor file;

   public LayoutResourcesServlet()
   {
      this.file = new FileProcessor();
   }

   /*
    * (non-Javadoc)
    * 
    * @see javax.servlet.http.HttpServlet#doGet(javax.servlet.http.HttpServletRequest,
    *      javax.servlet.http.HttpServletResponse)
    */
   protected void doGet(HttpServletRequest req, HttpServletResponse resp) throws IOException, ServletException
   {
      handle(req, resp);
   }

   /*
    * (non-Javadoc)
    * 
    * @see javax.servlet.http.HttpServlet#doPost(javax.servlet.http.HttpServletRequest,
    *      javax.servlet.http.HttpServletResponse)
    */
   protected void doPost(HttpServletRequest req, HttpServletResponse resp) throws IOException, ServletException
   {
         handle(req, resp);
   }

   public void handle(HttpServletRequest req, HttpServletResponse resp) throws IOException, ServletException
   {
      String pathInfo = req.getPathInfo();
      String servletPath = req.getServletPath();

      if (pathInfo == null || pathInfo.length() == 0 || pathInfo.equals(PATH_ROOT))
      {
         resp.sendRedirect(req.getContextPath() + servletPath);
      }
      else if (StringUtils.endsWithIgnoreCase(pathInfo, ".js"))
      {
         file.doFile(req, resp, pathInfo, FileProcessor.MIME_JS);
      }
      else if (StringUtils.endsWithIgnoreCase(pathInfo, ".css"))
      {
         file.doFile(req, resp, pathInfo, FileProcessor.MIME_CSS);
      }
      else if (StringUtils.endsWithIgnoreCase(pathInfo, ".htm"))
      {
         file.doFile(req, resp, pathInfo, FileProcessor.MIME_HTML);
      }
      else if (StringUtils.endsWithIgnoreCase(pathInfo, ".jpg"))
      {
         file.doFile(req, resp, pathInfo, FileProcessor.MIME_JPG);
      }
      else if (StringUtils.endsWithIgnoreCase(pathInfo, ".gif"))
      {
         file.doFile(req, resp, pathInfo, FileProcessor.MIME_GIF);
      }
      else if (StringUtils.endsWithIgnoreCase(pathInfo, ".png"))
      {
         file.doFile(req, resp, pathInfo, FileProcessor.MIME_HTML);
      }
      else
      {
         log.warn("Page not found (" + pathInfo + ").");
         resp.sendError(HttpServletResponse.SC_NOT_FOUND);
      }
   }

}
