/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.springlayout.web.layout.taglib;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.jsp.JspException;
import javax.servlet.jsp.JspTagException;
import javax.servlet.jsp.PageContext;

import net.sf.springlayout.util.DateFormatUtil;
import net.sf.springlayout.web.layout.Form;
import net.sf.springlayout.web.layout.OnPageFieldInstance;
import net.sf.springlayout.web.security.PageAccessHolder;
import net.sf.springlayout.web.security.PageAccessManager;
import net.sf.springlayout.web.util.WebConstants;

import org.springframework.beans.BeanWrapper;
import org.springframework.beans.BeanWrapperImpl;
import org.springframework.util.StringUtils;
import org.springframework.web.context.WebApplicationContext;
import org.springframework.web.servlet.tags.HtmlEscapingAwareTag;


/**
 * @author Jon, Adam Boas
 *
 */
abstract public class AbstractFormTag extends HtmlEscapingAwareTag
{
   protected WebApplicationContext ctx;
   protected HttpServletRequest request;
   private StringBuffer output;
   private String enctype;
   private String action; 
   private List onPageFieldInstances;
   private StringBuffer formEndJavascipt;
   
   /**
    * Primarily for testing this allows the StringBuffer that this tag and it's children use to
    * append their html output to be set and re-acquired.
    *
    * Retrieves the output StringBuffer which this AbstractFieldTag is using to append html.
    * @return Returns the output which this AbstractFieldTag is using to append html.
    */
   public StringBuffer getOutput()
   {
      return output;
   }

   /**
    * Sets the output which this AbstractFieldTag will use to append html.
    * @param output Sets the output which this AbstractFieldTag will use to append html
    */
   public void setOutput(StringBuffer output)
   {
      this.output = output;
   }

   /**
    *Sets the enctype for this FormTag.
    * @param enctype Sets the enctype for this FormTag.
    */
   public void setEnctype(String enctype)
   {
      this.enctype = enctype;
   }

   /**
    * Sets this form's action. If this attribute is specified, it overrides the value configured
    * in Spring XML.
    */
   public void setAction(String action)
   {
      this.action = action;
   }

   protected int doStartTagInternal() throws JspTagException
   {
      this.init();
      Form form = getCurrentForm();
      
      this.output.append("<form name=\"");
      this.output.append(form.getFormName());
      this.output.append("\" id=\"");
      this.output.append(form.getFormName());
      this.output.append("\" action=\"");
      this.output.append((StringUtils.hasText(this.action))? this.action : form.getFormAction());
      if(StringUtils.hasText(this.enctype))
      {
         this.output.append("\" enctype=\""); 
         this.output.append(this.enctype);
      }
      this.output.append("\" method=\"post\">\n");
      
      //map of fieldnames and values that have been persisted over a redirect
      Map stateMap = (Map) request.getAttribute(WebConstants.STATE_MAP); 
      pageContext.setAttribute("isValidating", stateMap.get(WebConstants.VALIDATE_MODE_PARAM) );
      for (Iterator it = stateMap.keySet().iterator(); it.hasNext();)
      {
         String key = (String) it.next();
         this.output.append("<input type=\"hidden\" name=\"");
         this.output.append(key);
         this.output.append("\" id=\"");
         this.output.append(key);
         this.output.append("\" ");
         this.output.append("value=\"");
         this.output.append(stateMap.get(key));
         this.output.append("\" />\n");
      }
            
      try
      {
         pageContext.getOut().print(this.output);
      
      }
      catch(IOException e)
      {
         throw new JspTagException(e.getMessage());
      }

      // Expose the current panel for use by field tags
      request.setAttribute(WebConstants.CURRENT_FORM, form);

      //TODO: is this necessary?
      // Expose a BeanWrapper for the current command object so that fields can
      // access information about themselves without building one each.
      String commandName = request.getAttribute(WebConstants.COMMAND_NAME).toString();
      Object command = request.getAttribute(commandName);
      BeanWrapper beanWrapper = new BeanWrapperImpl(command);
      pageContext.setAttribute(WebConstants.BEAN_WRAPPER, beanWrapper);
      
      return EVAL_BODY_INCLUDE;

   }
   
   /**
    * Closes off the form, cleans up form variable from request and adds Javascript required by 
    * fields on the page.
    * 
    * @see javax.servlet.jsp.tagext.Tag#doEndTag()
    */
   public int doEndTag() throws JspException
   {
      // clear the output buffer for use in rendering the end tag and cleanup
      this.output = new StringBuffer();
      request.removeAttribute(WebConstants.CURRENT_FORM);
      pageContext.removeAttribute(WebConstants.BEAN_WRAPPER);
      
      String commandName = request.getAttribute(WebConstants.COMMAND_NAME).toString();
      Object command = request.getAttribute(commandName);
      try
      {
         PageAccessHolder pageAccessHolder = PageAccessManager.getPageAccessHolder();
         if (pageAccessHolder.isEditMode())
         {
            this.output.append("\n<script type=\"text/javascript\">\n");

            StringBuffer invalidFieldIds = new StringBuffer();

               for (Iterator  onPageFieldIter = this.onPageFieldInstances.iterator();onPageFieldIter.hasNext();)
               {
                  OnPageFieldInstance onPageField = (OnPageFieldInstance) onPageFieldIter.next();
                  
                  //mandatory javascript
                  this.output.append(onPageField.getJavascript(isValidationMode(request), command, this.getCurrentForm().getFormName()));

                  //set up a list of mandatory fields that have currently failed
                  if (onPageField.isFailedValidation(new BeanWrapperImpl(command)) &&
                        onPageField.getFieldId().indexOf("[-1]") == -1)
                  {
                     invalidFieldIds.append((invalidFieldIds.length() > 0 ? ",":""));
                     invalidFieldIds.append("document.forms['");
                     invalidFieldIds.append(this.getCurrentForm().getFormName());
                     invalidFieldIds.append("']['");
                     invalidFieldIds.append(onPageField.getFieldId());
                     invalidFieldIds.append("']");
                  }

            }
            
            this.output.append("var invalidFields = new Array(");
            this.output.append(invalidFieldIds);
            this.output.append(");\n");
            this.output.append("if(isValidateMode()){checkAllMandatories();}\n");
            this.addScreenPositioningJs(this.output);
            this.output.append("\n");
            this.output.append("var setupDisabledFields = function(){\n");
            this.output.append("var field;\n");
            this.output.append(this.formEndJavascipt);
            this.output.append("};\n");
            this.output.append("addEvent(window, 'load', setupDisabledFields);\n");
            
            
            
            this.output.append("var localizedFormat = '");
            this.output.append(DateFormatUtil.getLocalizedDateFormatForJsPicker(this.getRequestContext().getLocale()));
            this.output.append("';\n");
            this.output.append("</script>\n");
         }

         this.output.append("</form>");
         pageContext.getOut().write(this.output.toString());
      }
      catch (IOException e)
      {
         throw new JspTagException(e.getMessage());
      }
      return EVAL_PAGE;
   }

   /**
    * Initialises tag and verifiies it's state before proceeding
    */
   protected void init()
   {
      this.ctx = this.getRequestContext().getWebApplicationContext();
      this.request = (HttpServletRequest) this.pageContext.getRequest();
      this.pageContext.setAttribute(WebConstants.LAYOUT_FORM_TAG, this);
      this.onPageFieldInstances = new ArrayList();
      this.formEndJavascipt = new StringBuffer();
      pageContext.setAttribute(WebConstants.FORM_END_JAVASCRIPT, this.formEndJavascipt);
      this.output = new StringBuffer();

   }
   
   
   protected abstract Form getCurrentForm();
   protected abstract boolean isValidationMode(HttpServletRequest request);

   /**
    * @return the onPageFieldInstances
    */
   public List getOnPageFieldInstances()
   {
      return onPageFieldInstances;
   }
   
   
   /**
    * Helper method to get the Screen position field from the page context and append javascipt 
    * onload function if it exists
    * @param buffer to append javathis.output to.
    */
   private void addScreenPositioningJs(StringBuffer buffer)
   {
      String screenPosition =
            (String) this.pageContext.getAttribute(WebConstants.SCREEN_POSITION_PARAM, PageContext.REQUEST_SCOPE);
      
      if (screenPosition != null)
      {
         buffer.append("prependEventHandler(window, 'load', function() { positionScreen('");
         buffer.append(screenPosition);
         buffer.append("') }.closure(window));\n");
      }
   }
   
   
   
}
