/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.springlayout.web.layout.taglib;

/**
 * Renders a group of check boxes.
 */
public class CheckBoxTag extends AbstractFieldGroupTag
{
   private static final long serialVersionUID = -693961903471516269L;

   public void renderEachItem(StringBuffer output, Object checkboxObject, int index)
   {
      String confirmedPath = status == null ? this.pathIfNestedNull : status.getExpression();
      String value = deriveValue(checkboxObject);
      String checked = "";
      String display = status.getDisplayValue();
      if (status != null)
      {
         checked = (display != null && display.indexOf(value) != -1) ? "checked=\"checked\" " : "";
      }

      String label = deriveLabel(checkboxObject);
      output.append(this.prefix);
      output.append("<input type=\"checkbox\" name=\"");
      output.append(confirmedPath);
      output.append("\" id=\"");
      output.append(confirmedPath);
      // don't append an index to the first field in the group as it is the
      // master
      if (index != 0)
      {
         output.append("_");
         output.append(index);
      }
      output.append("\" value=\"");
      output.append(value);
      output.append("\" ");
      output.append(checked);
      this.appendCommonHtmlAttributes(output);
      this.appendAllApplicableCssClasses(output, false);
      output.append(" />");
      output.append(label);
      output.append(this.suffix);

   }

   /*
    * (non-Javadoc)
    * 
    * @see net.sf.springlayout.web.layout.taglib.AbstractHtmlAttributesTag#getBaseCssClass()
    */
   protected String getBaseCssClass()
   {
      return "checkbox";
   }

}
