/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sf.springlayout.web.layout.taglib;

import org.springframework.util.StringUtils;



/**
 * @author Adam Boas
 * Created on Apr 30, 2006
 */
public class CheckboxTrueFalseTag extends AbstractHtmlInputAttributesTag
{
   private static final long serialVersionUID = -8166414520110645500L;
   
   public CheckboxTrueFalseTag()
   {
      super();
      this.prependMap.put(ONCLICK_ATTRIBUTE, "triggerEvent('change',this);");
   }
   
   /* (non-Javadoc)
    * @see net.sf.springlayout.web.layout.taglib.AbstractFieldTag#buildEditModeOutput()
    */
   protected void appendEditModeOutput(StringBuffer output)
   {
      String confirmedPath = status == null ? this.pathIfNestedNull : status.getExpression();
      output.append("<input type=\"checkbox\" name=\"");
      output.append(confirmedPath);
      output.append("\" id=\"");
      output.append(confirmedPath);
      output.append("\" value=\"1\" ");
      if(status == null)
         output.append(" disabled=\"disabled\" ");
      else if("1".equals(status.getValue()) || "true".equals(status.getValue()))
         output.append("checked=\"checked\" ");
      this.appendCommonHtmlAttributes(output);
      this.appendAllApplicableCssClasses(output, false);
      output.append("/>");
      output.append("<input type=\"hidden\" name=\"_");
      output.append(confirmedPath);
      output.append("\" id=\"_");
      output.append(confirmedPath);
      output.append("\" value=\"0\"/>");
      this.appendAfterFieldIcons(output, confirmedPath);
   }
   
   /**
    * Appends any icons or javascript which need to be appended directly after the field is 
    * rendered.
    * 
    * @param output the StringBuffer to append the icon or javascript to.
    * @param confirmedPath the confirmedPath of the control associated with the icons or javascript
    */
   protected void appendAfterFieldIcons(StringBuffer output, String confirmedPath)
   {
      if(StringUtils.hasText(this.getHelpMessage()))
      {
         this.appendContextSensitiveHelp(output, confirmedPath);
      }
   }

   /* (non-Javadoc)
    * @see net.sf.springlayout.web.layout.taglib.AbstractHtmlAttributesTag#getBaseCssClass()
    */
   protected String getBaseCssClass()
   {
      return "checkbox";
   }

   /* (non-Javadoc)
    * @see net.sf.springlayout.web.layout.taglib.AbstractFieldTag#appendReadOnlyOutput(java.lang.StringBuffer)
    */
   protected void appendReadOnlyOutput(StringBuffer output)
   {
      String confirmedPath = status == null ? this.pathIfNestedNull : status.getExpression();
      String confirmedValue = status == null ? "" : status.getDisplayValue();
      output.append("<input type=\"checkbox\" name=\"");
      output.append(confirmedPath);
      output.append("\" id=\"");
      output.append(confirmedPath);
      output.append("\" value=\"1\" ");
      if("true".equals(confirmedValue))
         output.append("checked=\"checked\"");
      this.appendCommonHtmlAttributes(output);
      this.appendAllApplicableCssClasses(output, true);
      output.append(" disabled=\"disabled\" />");
      output.append("<input type=\"hidden\" name=\"_");
      output.append(confirmedPath);
      output.append("\"  value=\"0\"/>");
   }

}
