/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.springlayout.web.layout.taglib;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.tagext.Tag;

import org.springframework.util.StringUtils;
import org.springframework.web.servlet.tags.HtmlEscapingAwareTag;

/**
 * @auther Adam Boas
 * Created on Jan 3, 2007
 */
public class DataGridColumnTag extends HtmlEscapingAwareTag
{
   private static final long serialVersionUID = 1L;
   /**
    * Title to apply to the head of this column.
    */
   private String title;
   /**
    * Internastionalizable message key to use when retrieving the title for this column. Will
    * only be used if a title is not present.
    */
   private String titleKey;
   /**
    * CSS Class applied to the 'th' at the top of this column.
    */
   private String headerClass;
   /**
    * CSS Class applied to each 'td' in this column.
    */
   private String cellClass;

   /* (non-Javadoc)
    * @see javax.servlet.jsp.tagext.BodyTagSupport#doStartTag()
    */
   public int doStartTagInternal() throws JspException
   {
      DataGridTag grid = (DataGridTag)this.getParent();
      if(grid.isEvaluatingHead())
      {
         DataGridTag.write(this.pageContext.getOut(), 
               "<th" + this.getHeaderClass() + ">" + this.getControlTitleText());
         grid.incrementColumnCount();
         return Tag.SKIP_BODY;
      }
      else if(grid.isEvaluatingEmptyContent() && !grid.isEvaluatingExtraRow())
      {
         return Tag.SKIP_BODY;
      }
      else
      {
         DataGridTag.write(this.pageContext.getOut(), "<td" + this.getCellClass() + ">");
         return Tag.EVAL_BODY_INCLUDE;
      }
   }
   
   /* (non-Javadoc)
    * @see javax.servlet.jsp.tagext.BodyTagSupport#doEndTag()
    */
   public int doEndTag() throws JspException
   {
      DataGridTag grid = (DataGridTag)this.getParent();
      if(grid.isEvaluatingHead())
         DataGridTag.write(this.pageContext.getOut(), "</th>");
      else if(!grid.isEvaluatingEmptyContent())
         DataGridTag.write(this.pageContext.getOut(), "</td>");
      return Tag.EVAL_PAGE;
   }
   
   
   /**
    * @return the correct title for this column (either text or a message value).
    */
   String getControlTitleText() 
   {
      String titleText;
      if(this.title == null && this.titleKey != null)
         titleText = this.getRequestContext().getMessage(this.titleKey, null, isHtmlEscape());
      else
         titleText = this.title;
      
      return titleText == null ? "" :titleText;
   }

   /**
    * Sets the title for this DataGridColumnTag.
    * @param title Sets the title for this DataGridColumnTag.
    */
   public void setTitle(String title)
   {
      this.title = title;
   }

   /**
    * Sets the titleKey for this DataGridColumnTag.
    * @param titleKey Sets the titleKey for this DataGridColumnTag.
    */
   public void setTitleKey(String titleKey)
   {
      this.titleKey = titleKey;
   }

   /**
    * Retrieves the cellClass for this DataGridColumnTag.
    * @return Returns the cellClass for this DataGridColumnTag.
    */
   String getCellClass()
   {
      if(StringUtils.hasText(this.cellClass))
         return " class=\"" + this.cellClass + "\"";
      return "";
   }

   /**
    * Sets the cellClass for this DataGridColumnTag.
    * @param cellClass Sets the cellClass for this DataGridColumnTag.
    */
   public void setCellClass(String cellClass)
   {
      this.cellClass = cellClass;
   }

   /**
    * Retrieves the headerClass for this DataGridColumnTag.
    * @return Returns the headerClass for this DataGridColumnTag.
    */
   public String getHeaderClass()
   {
      if(StringUtils.hasText(this.headerClass))
         return " class=\"" + this.headerClass + "\"";
      return "";
   }

   /**
    * Sets the headerClass for this DataGridColumnTag.
    * @param headerClass Sets the headerClass for this DataGridColumnTag.
    */
   public void setHeaderClass(String headerClass)
   {
      this.headerClass = headerClass;
   }

}
