/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.springlayout.web.layout.taglib;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.tagext.Tag;

import net.sf.springlayout.web.security.PageAccessHolder;
import net.sf.springlayout.web.security.PageAccessManager;

import org.springframework.util.StringUtils;


/**
 * @auther Adam Boas
 * Created on Jan 7, 2007
 */
public class DataGridRemoveColumnTag extends DataGridColumnTag
{
   private static final long serialVersionUID = -6790491455073855577L;
   /**
    * Determines whether this Remove control is a link or a button. Valid values are 'link' or
    * 'button'.
    */
   private String type;
   /**
    * The text which will appear on the removeControl.
    */
   private String removeControlTitle;
   /**
    * Internastionalizable message key to use when retrieving the title for the 'add' button. Will
    * only be used if an removeControlTitle is not present.
    */
   private String removeControlTitleKey;
   /**
    * CSS Class which will be applied to the 'add' button for this grid.
    */
   private String removeControlClass;
   /**
    * The text which will appear on the cancelControl.
    */
   private String cancelControlTitle;
   /**
    * Internastionalizable message key to use when retrieving the title for the 'add' button. Will
    * only be used if an cancelControlTitle is not present.
    */
   private String cancelControlTitleKey;
   /**
    * CSS Class which will be applied to the 'add' button for this grid.
    */
   private String cancelControlClass;

   /* (non-Javadoc)
    * @see javax.servlet.jsp.tagext.BodyTagSupport#doStartTag()
    */
   public int doStartTagInternal() throws JspException
   {
      DataGridTag grid = (DataGridTag)this.getParent();
      PageAccessHolder pageAccessHolder = PageAccessManager.getPageAccessHolder();
      StringBuffer output = new StringBuffer();
      if(grid.isEvaluatingHead())
      {
         output.append("<th");
         output.append(this.getHeaderClass());
         output.append(">");
         output.append(this.getControlTitleText());
         DataGridTag.write(this.pageContext.getOut(),  output.toString() );
         ((DataGridTag)this.getParent()).incrementColumnCount();
         return Tag.SKIP_BODY;
      }
      else if(grid.isEvaluatingEmptyContent() && !grid.isEvaluatingExtraRow())
      {
         return Tag.SKIP_BODY;
      }
      else
      {
         output.append("<td");
         output.append(this.getCellClass());
         output.append(">");
         if(pageAccessHolder.isEditMode())
         {
            this.appendRemoveControl(output);
            this.appendCancelControl(output);
         }
         DataGridTag.write(this.pageContext.getOut(),output.toString());
         return Tag.EVAL_BODY_INCLUDE;
      }
   }
   
   /* (non-Javadoc)
    * @see javax.servlet.jsp.tagext.BodyTagSupport#doEndTag()
    */
   public int doEndTag() throws JspException
   {
      DataGridTag grid = (DataGridTag)this.getParent();
      if(grid.isEvaluatingHead())
         DataGridTag.write(this.pageContext.getOut(), "</th>");
      else if(!grid.isEvaluatingEmptyContent())
         DataGridTag.write(this.pageContext.getOut(), "</td>");
      return Tag.EVAL_PAGE;
   }
   
   private void appendRemoveControl(StringBuffer output)
   {
      DataGridTag grid = (DataGridTag)this.getParent();
      output.append("link".equals(this.type) ? "<a href=\"#\"" : "<button type=\"button\"");
      output.append(this.getRemoveControlClass());
      output.append(" id=\"");
      output.append(grid.getGridId());
      output.append("_");
      output.append(grid.getIndex());
      output.append("_removeControl\"");
      output.append(" onclick=\"removeRow('");
      output.append(grid.getGridId());
      output.append("', '");
      output.append(grid.getIndex());
      output.append("');\">");
      output.append(this.getRemoveControlTitleText());
      output.append("link".equals(this.type) ? "</a>" : "</button>");
   }
   
   private void appendCancelControl(StringBuffer output)
   {
      DataGridTag grid = (DataGridTag)this.getParent();
      output.append("link".equals(this.type) ? "<a href=\"#\"" : "<button type=\"button\"");
      output.append(this.getCancelControlClass());
      output.append(" id=\"");
      output.append(grid.getGridId());
      output.append("_");
      output.append(grid.getIndex());
      output.append("_cancelControl\"");
      output.append(" onclick=\"replaceRow('");
      output.append(grid.getGridId());
      output.append("', '");
      output.append(grid.getIndex());
      output.append("');\" style=\"position:absolute;visibility:hidden;\">");
      output.append(this.getCancelControlTitleText());
      output.append("link".equals(this.type) ? "</a>" : "</button>");
   }

   /**
    * Sets the type for this DataGridRemoveColumnTag.
    * @param type Sets the type for this DataGridRemoveColumnTag.
    */
   public void setType(String type)
   {
      this.type = type;
   }

   /**
    * Sets the removeControlClass for this DataGridRemoveColumnTag.
    * @param removeControlClass Sets the removeControlClass for this DataGridRemoveColumnTag.
    */
   public void setRemoveControlClass(String removeControlClass)
   {
      this.removeControlClass = removeControlClass;
   }

   /**
    * Sets the removeControlTitleKey for this DataGridRemoveColumnTag.
    * @param removeControlTitleKey Sets the removeControlTitleKey for this DataGridRemoveColumnTag.
    */
   public void setRemoveControlTitleKey(String removeControlTitleKey)
   {
      this.removeControlTitleKey = removeControlTitleKey;
   }

   /**
    * Sets the removeControlTitle for this DataGridRemoveColumnTag.
    * @param removeControlTitle Sets the removeControlTitle for this DataGridRemoveColumnTag.
    */
   public void setRemoveControlTitle(String removeControlTitle)
   {
      this.removeControlTitle = removeControlTitle;
   }
   
   /**
    * @return the correct title for the removeControl in this column (either text or a message value).
    */
   String getRemoveControlTitleText() 
   {
      String titleText;
      if(this.removeControlTitle == null && this.removeControlTitleKey != null)
         titleText = this.getRequestContext().getMessage(this.removeControlTitleKey, null, isHtmlEscape());
      else
         titleText = this.removeControlTitle;
      
      return titleText == null ? "" :titleText;
   }
   
   /**
    * @return the label and value for the class to be applied to the remove removeControl or an 
    * empty string if none has been set.
    */
   String getRemoveControlClass()
   {
      if(StringUtils.hasText(this.removeControlClass))
         return " class=\"" + this.removeControlClass + "\"";
      return "";
   }
   
   /**
    * Sets the cancelControlClass for this DataGridRemoveColumnTag.
    * @param cancelControlClass Sets the cancelControlClass for this DataGridRemoveColumnTag.
    */
   public void setCancelControlClass(String cancelControlClass)
   {
      this.cancelControlClass = cancelControlClass;
   }

   /**
    * Sets the cancelControlTitleKey for this DataGridRemoveColumnTag.
    * @param cancelControlTitleKey Sets the cancelControlTitleKey for this DataGridRemoveColumnTag.
    */
   public void setCancelControlTitleKey(String cancelControlTitleKey)
   {
      this.cancelControlTitleKey = cancelControlTitleKey;
   }

   /**
    * Sets the cancelControlTitle for this DataGridRemoveColumnTag.
    * @param cancelControlTitle Sets the cancelControlTitle for this DataGridRemoveColumnTag.
    */
   public void setCancelControlTitle(String cancelControlTitle)
   {
      this.cancelControlTitle = cancelControlTitle;
   }
   
   /**
    * @return the correct title for the cancelControl in this column (either text or a message value).
    */
   String getCancelControlTitleText() 
   {
      String titleText;
      if(this.cancelControlTitle == null && this.cancelControlTitleKey != null)
         titleText = this.getRequestContext().getMessage(this.cancelControlTitleKey, null, isHtmlEscape());
      else
         titleText = this.cancelControlTitle;
      
      return titleText == null ? "" :titleText;
   }
   
   /**
    * @return the label and value for the class to be applied to the remove cancelControl or an 
    * empty string if none has been set.
    */
   String getCancelControlClass()
   {
      if(StringUtils.hasText(this.cancelControlClass))
         return " class=\"" + this.cancelControlClass + "\"";
      return "";
   }

}
