/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.springlayout.web.layout.taglib;

import net.sf.springlayout.web.layout.FieldDefinition;
import net.sf.springlayout.web.layout.OnPageFieldInstance;

import org.springframework.util.StringUtils;


/**
 * If saveFieldValue is set to true a hidden field is rendered to the html that can be updated using
 * javascript and submitted with the form. If the saveFieldValue property is set to false (default),
 * the hidden field is rendered as disabled so it's value is not persisted with a submission of the
 * form but a valid field is still in place so field label has valid xhtml.
 * 
 * @author Adam Boas, Rob Monie 
 * Created on 24/04/2006
 */
public class DisplayTag extends AbstractHtmlAttributesTag
{

   private static final long serialVersionUID = -245626102096623455L;
   private Boolean saveFieldValue = Boolean.FALSE;

   /**
    * Sets the saveFieldValue property for the field tag.
    * @param saveFieldValue
    */
   public void setSaveFieldValue(Boolean saveFieldValue)
   {
      this.saveFieldValue = saveFieldValue;
   }

   /* (non-Javadoc)
    * @see net.sf.springlayout.web.layout.taglib.AbstractFieldTag#appendEditModeOutput(java.lang.StringBuffer)
    */
   protected void appendEditModeOutput(StringBuffer output)
   {
      String confirmedPath = status == null ? this.pathIfNestedNull : status.getExpression();
      String confirmedValue = status == null ? "" : status.getDisplayValue();
      String displayValue = confirmedValue;
      if(!StringUtils.hasText(confirmedValue) && StringUtils.hasText(this.emptyDisplayString))
         displayValue = this.emptyDisplayString;
      output.append("<span id=\"");
      output.append(confirmedPath);
      output.append("_display\" ");
      this.appendAllApplicableCssClasses(output, false);
      output.append(">");
      output.append(displayValue);
      output.append("</span>");
      output.append("<input type=\"hidden\" name=\"");
      output.append(confirmedPath);
      output.append("\" id=\"");
      output.append(confirmedPath);
      output.append("\" value=\"");
      output.append(confirmedValue);
      output.append("\" ");
      this.appendCommonHtmlAttributes(output);
      if(!this.saveFieldValue.booleanValue() || status == null) 
         output.append(" disabled=\"disabled\" ");
      output.append("/>");
   }


   /* (non-Javadoc)
    * @see net.sf.springlayout.web.layout.taglib.AbstractHtmlAttributesTag#getBaseCssClass()
    */
   protected String getBaseCssClass()
   {
      return "displayField";
   }

   /* (non-Javadoc)
    * @see net.sf.springlayout.web.layout.taglib.AbstractHtmlAttributesTag#addToFieldSet(net.sf.springlayout.web.layout.FieldDefinition, net.sf.springlayout.web.layout.OnPageFieldInstance)
    */
   protected void addToFieldSet(FieldDefinition fieldDefinition, OnPageFieldInstance fieldInstance)
   {
      //TODO: not required as never editable
      
   }
}
