/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.springlayout.web.layout.taglib;

import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.jsp.JspException;
import javax.servlet.jsp.JspTagException;
import javax.servlet.jsp.JspWriter;
import javax.servlet.jsp.PageContext;
import javax.servlet.jsp.tagext.TagSupport;

import org.apache.commons.lang.StringUtils;
import org.springframework.web.servlet.support.BindStatus;
import org.springframework.web.servlet.tags.HtmlEscapingAwareTag;
import org.springframework.web.servlet.tags.NestedPathTag;
import org.springframework.web.util.ExpressionEvaluationUtils;

/**
 * shows errors for the path specified... if multiple errors exist for the path, generates an unordered list
 * 
 * @author Rob Monie
 * 
 */
public class ErrorsTag extends HtmlEscapingAwareTag
{

   private static final long serialVersionUID = 8041505133654275578L;

   private String path;

   /**
    * Set the path that this tag should apply. Can be a bean (e.g. "person") to
    * get global errors, or a bean property (e.g. "person.name") to get field
    * errors (also supporting nested fields and "person.na*" mappings).
    * "person.*" will return all errors for the specified bean, both global and
    * field errors.
    */
   public void setPath(String path)
   {
      this.path = path;
   }

   protected final int doStartTagInternal() throws ServletException, JspException
   {

      String resolvedPath = ExpressionEvaluationUtils.evaluateString("path", this.path, pageContext);

      String nestedPath = (String) pageContext.getAttribute(NestedPathTag.NESTED_PATH_VARIABLE_NAME,
            PageContext.REQUEST_SCOPE);
      if (nestedPath != null)
      {
         resolvedPath = nestedPath + resolvedPath;
      }
      BindStatus status = null;
      try
      {
         status =  new BindStatus(getRequestContext(), resolvedPath, isHtmlEscape());
      }
      catch (IllegalStateException ex)
      {
         throw new JspTagException(ex.getMessage());
      }

      String[] errors = status.getErrorMessages();
      JspWriter out = this.pageContext.getOut();
      try
      {
         if (StringUtils.indexOf(path,"*") == path.length() -1)
         {
            if(errors.length > 0)
            {
               out.write("<ul class=\"errors\">\n");
               for (int ii = 0; ii < errors.length; ii++)
               {
                  out.write("<li>" + errors[ii] + "</li>\n");
               }
               out.write("</ul>\n");
            }
         }
         else if (errors.length == 1)
         {
               out.write(errors[0]);
   
         }
      }
      catch (IOException e)
      {
         throw new JspTagException(e.getMessage());
      }

      return TagSupport.SKIP_BODY;
   }
}
