/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.springlayout.web.layout.taglib;

import net.sf.springlayout.web.layout.FieldDefinition;
import net.sf.springlayout.web.layout.LayoutUtils;
import net.sf.springlayout.web.layout.OnPageFieldInstance;
import net.sf.springlayout.web.util.WebConstants;

/**
 * Generates a field label
 * @author Rob Monie
 * 
*/
public class FieldLabelTag extends AbstractHtmlAttributesTag
{
   
   private static final long serialVersionUID = -4739903392228501053L;
   public String suffix = ":";
   private String value;

 
   /**
    * Sets the field suffix- defaults to ":"
    * @param suffix
    */
   public void setSuffix(String suffix) {
      this.suffix = suffix;      
   }

   /**
    *Sets the value for this FieldLabelTag.
    * @param value Sets the value for this FieldLabelTag.
    */
   public void setValue(String value)
   {
      this.value = value;
   }

   /* (non-Javadoc)
    * @see net.sf.springlayout.web.layout.taglib.AbstractHtmlAttributesTag#getBaseCssClass()
    */
   protected String getBaseCssClass()
   {
      return "fieldLabel";
   }

   /* (non-Javadoc)
    * @see net.sf.springlayout.web.layout.taglib.AbstractFieldTag#appendEditModeOutput(java.lang.StringBuffer)
    */
   protected void appendEditModeOutput(StringBuffer output)
   {
      String confirmedPath = status == null ? this.pathIfNestedNull : status.getExpression();
      output.append("<label for=\"");
      output.append(confirmedPath);
      output.append("\" id=\"");
      output.append(confirmedPath);
      output.append("_label\" ");
      this.appendAllApplicableCssClasses(output, false);
      this.appendCommonHtmlAttributes(output);
      output.append(">");
      output.append(getFieldLabel());
      output.append("</label>");
      
      //Add javascript to disable field and label properly unless child field is a hidden field
      StringBuffer formEndJavascript = (StringBuffer)pageContext.getAttribute(WebConstants.FORM_END_JAVASCRIPT);
      formEndJavascript.append("field = $('");
      formEndJavascript.append(confirmedPath);
      formEndJavascript.append("');");
      formEndJavascript.append("if(field != null && field.disabled && field.type != 'hidden') {");
      
      formEndJavascript.append("for(var i = 0 ; i < field.fieldLabelsForError.length ; i++) {");
      formEndJavascript.append("Element.addClassName(");
      formEndJavascript.append("field.fieldLabelsForError[i],'disabled');");
      formEndJavascript.append("}}\n");
   }

   /* (non-Javadoc)
    * @see net.sf.springlayout.web.layout.taglib.AbstractFieldTag#appendReadOnlyOutput(java.lang.StringBuffer)
    */
   protected void appendReadOnlyOutput(StringBuffer output)
   {
      
      String confirmedPath = status == null ? this.pathIfNestedNull : status.getExpression();
      output.append("<span id=\"");
      output.append(confirmedPath);
      output.append("_label\" ");
      this.appendAllApplicableCssClasses(output, true);
      output.append(">");
      output.append(getFieldLabel());
      output.append("</span>");
      
   }

   /* (non-Javadoc)
    * @see net.sf.springlayout.web.layout.taglib.AbstractFieldTag#appendMultiModeOutput(java.lang.StringBuffer)
    */
   protected void appendMultiModeOutput(StringBuffer output)
   {
      //Labels call through to edit mode as in multi-mode there is a control on the page.,
      this.appendEditModeOutput(output);
   }
   
   private String getFieldLabel() 
   {
      String fieldLabel;
      if(this.value == null)
      {
         String strippedPath = LayoutUtils.getStrippedPropertyPath(path);
         fieldLabel = this.getRequestContext().getMessage(strippedPath, null, isHtmlEscape()) + this.suffix;
      }
      else
         fieldLabel = this.value + this.suffix;
      
      return fieldLabel;
   }

   /* (non-Javadoc)
    * @see net.sf.springlayout.web.layout.taglib.AbstractHtmlAttributesTag#addToFieldSet(net.sf.springlayout.web.layout.FieldDefinition, net.sf.springlayout.web.layout.OnPageFieldInstance)
    */
   protected void addToFieldSet(FieldDefinition fieldDefinition, OnPageFieldInstance fieldInstance)
   {
      //Not required as not editable
      
   }
   
   
}
