/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.springlayout.web.layout.taglib;

import javax.servlet.ServletException;
import javax.servlet.jsp.JspException;
import javax.servlet.jsp.JspTagException;
import javax.servlet.jsp.PageContext;
import javax.servlet.jsp.tagext.TagSupport;

import org.springframework.web.servlet.support.BindStatus;
import org.springframework.web.servlet.tags.HtmlEscapingAwareTag;
import org.springframework.web.servlet.tags.NestedPathTag;
import org.springframework.web.util.ExpressionEvaluationUtils;

/**
 * Iterates over errors against the given path.
 * @author Rob Monie
 *
 */
public class ForEachErrorTag extends HtmlEscapingAwareTag
{
   
   private static final long serialVersionUID = 8041505133654275578L;
   
    /**
     * Name of the exposed variable within the scope of this tag: "status".
     */
    public static final String STATUS_VARIABLE_NAME = "status";

    private String path;

    private String[] errors;
    private BindStatus status;
    private int index;
    private String var;


    /**
     * Set the path that this tag should apply. Can be a bean (e.g. "person")
     * to get global errors, or a bean property (e.g. "person.name") to get
     * field errors (also supporting nested fields and "person.na*" mappings).
     * "person.*" will return all errors for the specified bean, both global
     * and field errors.
     */
    public void setPath(String path) {
        this.path = path;
    }

    /**
     * Return the name of the bean that this tag checks.
     */
    public String getPath() {
        return path;
    }


    /**
     * Set the name of the variable to be exposed for each iteration of the tag
    * @param var
    */
   public void setVar(String var)
   {
      this.var = var;
   }

   protected final int doStartTagInternal() throws ServletException, JspException {
       
       String resolvedPath = ExpressionEvaluationUtils.evaluateString("path", getPath(), pageContext);


            String nestedPath = (String) pageContext.getAttribute(
                    NestedPathTag.NESTED_PATH_VARIABLE_NAME, PageContext.REQUEST_SCOPE);
            if (nestedPath != null) {
                resolvedPath = nestedPath + resolvedPath;
            }

        try {
            this.status = new BindStatus(getRequestContext(), resolvedPath, isHtmlEscape());
        }
        catch (IllegalStateException ex) {
            throw new JspTagException(ex.getMessage());
        }
        
        this.errors = status.getErrorMessages();
       if(index < errors.length)
       {
          pageContext.setAttribute(var, errors[this.index]);
          return TagSupport.EVAL_BODY_INCLUDE;
       }
        else {
            return TagSupport.SKIP_BODY;
        }
    }

    public int doEndTag() {
        this.pageContext.removeAttribute(var);
        return EVAL_PAGE;
    }

   public int doAfterBody() throws JspException
   {
      
      this.index ++;
      if(this.index < errors.length)
      {
         pageContext.setAttribute(var, errors[this.index]);
         return TagSupport.EVAL_BODY_AGAIN;
      } else
      {
         return TagSupport.SKIP_BODY;
      }
   }

   public void doFinally()
   {
      this.errors = null;
      this.index = 0;
      this.path = null;
      this.status = null;
   }
   
   

}
