/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.springlayout.web.layout.taglib;

import javax.servlet.http.HttpServletRequest;

import net.sf.springlayout.web.layout.Form;

/**
 * <p>
 * FormTag outputs exposes the form definition bean to the page and generates opening and closing
 * form tags.
 * </p>
 * <p>
 * This tag extends the base Spring tag classhierarcy providing features such as
 * <ul>
 * <li>Access to the <code>WebApplicationContext</code> through the <code>RequestContext</code></li>
 * <li>Escaping of html to be xhtml compliant</li>
 * <li>Locale & messages</li>
 * </ul>
 * </p>
 * 
 * @author Rob Monie, Adam Boas
 * 
 */
public class FormTag extends AbstractFormTag
{

   private static final long serialVersionUID = -1440738102628543789L;

   private Form form;
   private String formBeanName;

   /**
    * @param formBeanName The formBeanName to set.
    */
   public void setFormBeanName(String formBeanName)
   {
      this.formBeanName = formBeanName;
   }

   /**
    * Initialises tag and verifiies it's state before proceeding
    */
   protected void init()
   {
      super.init();
      this.form = (Form) ctx.getBean(formBeanName);

      // cannot continue if no form present
      if (this.form == null)
      {
         throw new NullPointerException("Invalid form bean name supplied to tag. ");
      }
   }

   /*
    * (non-Javadoc)
    * 
    * @see javax.servlet.jsp.tagext.TryCatchFinally#doFinally()
    */
   public void doFinally()
   {
      super.doFinally();
      this.ctx = null;
      this.formBeanName = null;
      this.form = null;
   }

   protected boolean isValidationMode(HttpServletRequest request)
   {
      // Form tag is always in validation mode.
      return true;
   }

   /*
    * (non-Javadoc)
    * 
    * @see net.sf.springlayout.web.layout.taglib.AbstractFormTag#getCurrentForm()
    */
   protected Form getCurrentForm()
   {
      return form;
   }
}
