/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.springlayout.web.layout.taglib;

import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.jsp.JspException;
import javax.servlet.jsp.JspTagException;
import javax.servlet.jsp.tagext.TagSupport;

import net.sf.springlayout.util.SpringLayoutConfiguration;
import net.sf.springlayout.web.util.WebConstants;

import org.apache.commons.lang.StringUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.web.servlet.tags.HtmlEscapingAwareTag;

/**
 * Renders Javascript and css imports and sets up an required javascript
 * variables
 * 
 * @author Rob Monie
 * 
 */
public class LayoutConfigTag extends HtmlEscapingAwareTag
{

   private static final long serialVersionUID = 8041505133654275578L;
   Log log = LogFactory.getLog(LayoutConfigTag.class);
   private static SpringLayoutConfiguration config = SpringLayoutConfiguration.getInstance();

   private boolean showLoadingMessage = true;
   private StringBuffer output;
   
   
   /**
    * Primarily for testing this allows the StringBuffer that this tag and it's children use to
    * append their html output to be set and re-acquired.
    *
    * Retrieves the output StringBuffer which this AbstractFieldTag is using to append html.
    * @return Returns the output which this AbstractFieldTag is using to append html.
    */
   public StringBuffer getOutput()
   {
      return output;
   }

   /**
    * Sets the output which this AbstractFieldTag will use to append html.
    * @param output Sets the output which this AbstractFieldTag will use to append html
    */
   public void setOutput(StringBuffer output)
   {
      this.output = output;
   }

   /**
    * Should the loading progress message be used on this page. Default is true.
    * 
    * @param showLoadingMessage
    *           the showLoadingMessage to set
    */
   public void setShowLoadingMessage(boolean showLoadingMessage)
   {
      this.showLoadingMessage = showLoadingMessage;
   }

   protected final int doStartTagInternal() throws ServletException, JspException
   {

      HttpServletRequest request = (HttpServletRequest) pageContext.getRequest();

      String contextPath = request.getContextPath();

      output = new StringBuffer();

      output.append("<link href=\"");
      output.append(contextPath);
      output.append("/layoutResources/styles/formstyle.css\" rel=\"stylesheet\" type=\"text/css\" media=\"screen\" />\n");
      output.append("<link href=\"");
      output.append(contextPath);
      output.append("/layoutResources/styles/layout.css\" rel=\"stylesheet\" type=\"text/css\" media=\"screen\" />\n");
      output.append("<link href=\"");
      output.append(contextPath);
      output
            .append("/layoutResources/styles/calendar-blue.css\" rel=\"stylesheet\" type=\"text/css\" media=\"screen\" />\n");
      output.append("<link href=\"");
      output.append(contextPath);
      output.append("/layoutResources/styles/calendar.css\" rel=\"stylesheet\" type=\"text/css\" media=\"screen\" />\n");

      String cssLocationString = config.getProperty("applicationStyleSheet.locations");

      if (cssLocationString != null && !"".equals(cssLocationString))
      {
         // Add any application specific css files
         String[] appCssLocations = StringUtils.split(cssLocationString, ",");

         for (int ii = 0; ii < appCssLocations.length; ii++)
         {
            output.append("<link href=\"");
            output.append(contextPath);
            output.append(StringUtils.trim(appCssLocations[ii])
                  + "\" rel=\"stylesheet\" type=\"text/css\" media=\"screen\" />\n");
         }
      }

      output.append("<script language=\"JavaScript\" type=\"text/javascript\" src=\"");
      output.append(contextPath);
      output.append("/layoutResources/scripts/prototype.js\"></script>\n");

      output.append("<script language=\"JavaScript\" type=\"text/javascript\" src=\"");
      output.append(contextPath);
      output.append("/layoutResources/scripts/behaviour.js\"></script>\n");

      output.append("<script language=\"JavaScript\" type=\"text/javascript\" src=\"");
      output.append(contextPath);
      output.append("/layoutResources/scripts/yahoo-min.js\"></script>\n");

      output.append("<script language=\"JavaScript\" type=\"text/javascript\" src=\"");
      output.append(contextPath);
      output.append("/layoutResources/scripts/event.js\"></script>\n");

      output.append("<script language=\"JavaScript\" type=\"text/javascript\" src=\"");
      output.append(contextPath);
      output.append("/layoutResources/scripts/dateUtils.js\"></script>\n");

      output.append("<script language=\"JavaScript\" type=\"text/javascript\" src=\"");
      output.append(contextPath);
      output.append("/layoutResources/scripts/layout-closure.js\"></script>\n");

      output.append("<script language=\"JavaScript\" type=\"text/javascript\" src=\"");
      output.append(contextPath);
      output.append("/layoutResources/scripts/layout.js\"></script>\n");

      output.append("<script language=\"JavaScript\" type=\"text/javascript\" src=\"");
      output.append(contextPath);
      output.append("/layoutResources/scripts/layout-grid.js\"></script>\n");

      output.append("<script language=\"JavaScript\" type=\"text/javascript\" src=\"");
      output.append(contextPath);
      output.append("/layoutResources/scripts/layoutAddEvents.js\"></script>\n");

      output.append("<script language=\"JavaScript\" type=\"text/javascript\" src=\"");
      output.append(contextPath);
      output.append("/layoutResources/scripts/layout-validation.js\"></script>\n");

      output.append("<script language=\"JavaScript\" type=\"text/javascript\" src=\"");
      output.append(contextPath);
      output.append("/layoutResources/scripts/calendar/calendar.js\"></script>\n");

      output.append("<script language=\"JavaScript\" type=\"text/javascript\" src=\"");
      output.append(contextPath);
      output.append("/layoutResources/scripts/lang/calendar-en.js\"></script>\n");

      output.append("<script language=\"JavaScript\" type=\"text/javascript\" src=\"");
      output.append(contextPath);
      output.append("/layoutResources/scripts/calendar/calendar-setup.js\"></script>\n");

      output.append("<script language=\"JavaScript\" type=\"text/javascript\" src=\"");
      output.append(contextPath);
      output.append("/layoutResources/scripts/scriptaculous/builder.js\"></script>\n");

      output.append("<script language=\"JavaScript\" type=\"text/javascript\" src=\"");
      output.append(contextPath);
      output.append("/layoutResources/scripts/scriptaculous/effects.js\"></script>\n");

      output.append("<script language=\"JavaScript\" type=\"text/javascript\" src=\"");
      output.append(contextPath);
      output.append("/layoutResources/scripts/scriptaculous/controls.js\"></script>\n");

      output.append("<script language=\"JavaScript\" type=\"text/javascript\" src=\"");
      output.append(contextPath);
      output.append("/layoutResources/scripts/scriptaculous/dragdrop.js\"></script>\n");

      output.append("<script language=\"JavaScript\" type=\"text/javascript\" src=\"");
      output.append(contextPath);
      output.append("/layoutResources/scripts/scriptaculous/scriptaculous.js\"></script>\n");

      output.append("<script language=\"JavaScript\" type=\"text/javascript\" src=\"");
      output.append(contextPath);
      output.append("/layoutResources/scripts/scriptaculous/slider.js\"></script>\n");

      output.append("<script language=\"JavaScript\" type=\"text/javascript\" src=\"");
      output.append(contextPath);
      output.append("/layoutResources/scripts/autocomplete.js\"></script>\n");

      output.append("<script language=\"JavaScript\" type=\"text/javascript\">\n");
      output.append("appPath = \"");
      output.append(contextPath);
      output.append("\";\n");
      if (log.isDebugEnabled())
      {
         output.append("var layoutDebug = true;\n");
      }
      else
      {
         output.append("var layoutDebug = false;\n");
      }

      output.append("var showLoadingMessage = " + this.showLoadingMessage + ";");

      output.append("</script>\n");

      request.setAttribute(WebConstants.SHOW_LOADING_MESSAGE, new Boolean(this.showLoadingMessage));

      try
      {
         pageContext.getOut().write(output.toString());
      }
      catch (IOException e)
      {
         throw new JspTagException(e.getMessage());
      }
      return TagSupport.SKIP_BODY;
   }
}
