/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.springlayout.web.layout.taglib;

import java.io.Writer;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import javax.servlet.jsp.JspTagException;

import net.sf.springlayout.util.SpringLayoutConfiguration;
import net.sf.springlayout.web.layout.OnPageFieldInstance;

import org.apache.commons.beanutils.BeanUtils;
import org.springframework.web.servlet.tags.RequestContextAwareTag;
import org.springframework.web.util.HtmlUtils;


/**
 * Generates options to be used within a select field
 * 
 * @author Rob Monie, Adam Boas
 * 
 */
public class OptionsTag extends RequestContextAwareTag
{

   private static final long serialVersionUID = -4755586781525798636L;
   private List items;
   private String label;
   private String value;
   private String defaultLabel;
   private String defaultValue;
   private String defaultLabelKey;
   protected static SpringLayoutConfiguration config = SpringLayoutConfiguration.getInstance();
   protected String emptyDisplayString = config.getProperty("fieldValue.readonly.empty.default");
   

   /**
    *Sets the emptyDisplayString for this InputFieldTag.
    * @param emptyDisplayString Sets the emptyDisplayString for this InputFieldTag.
    */
   public void setEmptyDisplayString(String emptyDisplayString)
   {
      this.emptyDisplayString = emptyDisplayString;
   }

   /**
    * @param items
    */
   public void setItems(List items)
   {
      this.items = items;
   }

   /**
    * @param label
    */
   public void setLabel(String label)
   {
      this.label = label;
   }

   /**
    * @param value
    */
   public void setValue(String value)
   {
      this.value = value;
   }

   /**
    * @param defaultLabel
    */
   public void setDefaultLabel(String defaultLabel)
   {
      this.defaultLabel = defaultLabel;
   }

   /**
    * @param defaultLabelKey
    */
   public void setDefaultLabelKey(String defaultLabelKey)
   {
      this.defaultLabelKey = defaultLabelKey;
   }

   /**
    * @param defaultValue
    */
   public void setDefaultValue(String defaultValue)
   {
      this.defaultValue = defaultValue;
   }

   /**
    * Gets the htmlEscape property for the options tag based on the parent tag.
    * @return is the tag to be html escaped
    */
   private boolean isHtmlEscape() 
   {
      SelectFieldTag parent = (SelectFieldTag)  this.getParent();
      if(parent != null)
      {
         return parent.isHtmlEscape();
      } else
      {
         return getRequestContext().isDefaultHtmlEscape(); 
      }
   }
   
   /*
    * (non-Javadoc)
    * 
    * @see net.sf.springlayout.web.layout.taglib.LayoutBindTag#doFieldStartTag()
    */
   public int doStartTagInternal() throws JspTagException
   {
      if (emptyDisplayString == null) {
         emptyDisplayString = config.getProperty("fieldValue.readonly.empty.default");
      }
      Writer out = super.pageContext.getOut();

      List selectedValues = (List) pageContext.getAttribute(SelectFieldTag.SELECTED_VALUES);

      OnPageFieldInstance fieldInstance = (OnPageFieldInstance) pageContext.getAttribute(SelectFieldTag.FIELD_STATUS_VARIABLE);

      if (this.items == null)
      {
         this.items = new ArrayList();
      }

      try
      {
         String htmlOut = null;
         if (fieldInstance.getReadOnly())
         {
            if (selectedValues.size() > 1)
            {
               for (Iterator it = selectedValues.iterator(); it.hasNext();)
               {
                  htmlOut = this.isHtmlEscape() ? "<li>" + HtmlUtils.htmlEscape(it.next().toString()) + "</li>"
                        : "<li>" + it.next().toString() + "</li>";
               }
            }
            else
            {
               if("".equals(selectedValues.get(0).toString()) && this.emptyDisplayString != null)
                  htmlOut = this.emptyDisplayString;
               else
                  htmlOut = this.isHtmlEscape() ? HtmlUtils.htmlEscape(selectedValues.get(0).toString()) : selectedValues
                     .get(0).toString();
            }

            out.write(htmlOut);

         }
         else
         {
            if (defaultLabelKey != null)
            {
               defaultLabel = this.getRequestContext().getMessage(defaultLabelKey, null, isHtmlEscape());
            }


            if (defaultLabel != null && defaultValue != null)
            {
               htmlOut = this.isHtmlEscape() ? "<option value=\"" + defaultValue + "\">"
                     + HtmlUtils.htmlEscape(defaultLabel) + "</option>" : "<option value=\"" + defaultValue + "\">"
                     + defaultLabel + "</option>";

               out.write(htmlOut);
            }

            for (Iterator it = items.iterator(); it.hasNext();)
            {
               Object currentItem = it.next();
               Object valueObj = BeanUtils.getProperty(currentItem, value);
               Object labelObj = BeanUtils.getProperty(currentItem, label);
               String actualValue = valueObj == null ? "": valueObj.toString();
               String actualLabel = labelObj == null ? "" : labelObj.toString();

               String selected = "";
               if (selectedValues.contains(actualValue))
               {
                  selected = "selected=\"selected\"";
               }

               htmlOut = this.isHtmlEscape() ? "<option value=\"" + actualValue + "\" " + selected + ">"
                     + HtmlUtils.htmlEscape (actualLabel) + "</option>" : "<option value=\"" + actualValue + "\" " + selected + ">"
                     + actualLabel + "</option>";

               out.write(htmlOut);

            }
         }

      }
      catch (Exception e)
      {
         throw new JspTagException(e.getMessage());
      }
      
      return SKIP_BODY;
   }

}
