/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.springlayout.web.layout.taglib;



/**
 * Renders a group of radio buttons.
 */
public class RadioButtonsTag extends AbstractFieldGroupTag
{
   private static final long serialVersionUID = 731352634882163875L;

   public void renderEachItem(StringBuffer output, Object radioObject, int index)
   {
      String confirmedPath = status == null ? this.pathIfNestedNull : status.getExpression();
      String radioValue = deriveValue(radioObject);
      String checked = "";
      if(status != null)
         checked = (radioValue.equals(status.getDisplayValue()))?
            "checked=\"checked\" " : "";
      
      String radioLabel = deriveLabel(radioObject);
      output.append(this.prefix);
      output.append("<input type=\"radio\" name=\"");
      output.append(confirmedPath);
      output.append("\" id=\"");
      output.append(confirmedPath);
      
      //don't append an index to the first field in the group as it is the master
      if(index != 0)
      {
         output.append("_");
         output.append(index);
      }
      output.append("\" value=\"");
      output.append(radioValue);
      output.append("\" ");
      output.append(checked);
      //trigger the event on the master field - the first of the group
      this.prependMap.put(ONCLICK_ATTRIBUTE, "triggerEvent('change',$('" + confirmedPath + "'));");
      
      //after the inital radio button has been rendered we want to 
      //remove the default onchange from the other fields in the group
      //to prevent browsers that support the change event for radiobuttons
      if(index == 1)
      {
         this.prependMap.remove(ONCHANGE_ATTRIBUTE);
      }
      
      this.appendCommonHtmlAttributes(output);
      this.appendAllApplicableCssClasses(output, false);
      output.append(" />");
      output.append(radioLabel);
      output.append(this.suffix);

   }
   
   /* (non-Javadoc)
    * @see net.sf.springlayout.web.layout.taglib.AbstractHtmlAttributesTag#getBaseCssClass()
    */
   protected String getBaseCssClass()
   {
      return "radioButton";
   }

}
