/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.springlayout.web.layout.taglib;

import java.io.IOException;
import java.io.Writer;
import java.util.ArrayList;
import java.util.List;

import javax.servlet.jsp.JspTagException;
import javax.servlet.jsp.tagext.TagSupport;

import org.apache.commons.collections.CollectionUtils;


/**
 * @author Adam Boas 
 * Created on 23/04/2006 
 */
public class SelectFieldTag extends AbstractHtmlInputAttributesTag
{

   public static String FIELD_STATUS_VARIABLE = "fieldStatus";
   public static String SELECTED_VALUES = "selectedValues";
   private static final long serialVersionUID = 7467496269381187929L;
   private Boolean multiple = Boolean.FALSE;
   private List selectedValues;
   private Integer size;


   /**
    * 
    */
   public SelectFieldTag()
   {
      super();
      this.selectedValues = new ArrayList();
   }

   /**
    * Sets the multiple property of the tag.
    * 
    * @param multiple
    */
   public void setMultiple(Boolean multiple)
   {
      this.multiple = multiple;
   }
   
   
   
   /**
    * @param size the size to set
    */
   public void setSize(Integer size)
   {
      this.size = size;
   }

   /**
    * Exposes the <,code>isHtmlEscape</code> method to a wider scope.  Allows the options tag to 
    * retrieve the htmlEscape property of the select tag.
    * @see org.springframework.web.servlet.tags.HtmlEscapingAwareTag#isHtmlEscape()
    */
   protected boolean isHtmlEscape() {
      return super.isHtmlEscape();
   }

   /*
    * (non-Javadoc)
    * 
    * @see net.sf.springlayout.web.layout.taglib.AbstractFieldTag#doFieldStartTag()
    */
   public int doFieldStartTag() throws JspTagException
   {
      String[] selectedIds;
      if(status != null)
      {
         if(this.fieldInstance.getReadOnly())
         {
            selectedIds = new String[] {status.getDisplayValue()};
         }
         else
         {
            selectedIds = status.getDisplayValue().split(",");
         }
      }
      else
      {
         selectedIds = new String[]{""};
      }
      selectedValues.clear();
      CollectionUtils.addAll(selectedValues, selectedIds);

      pageContext.setAttribute(SelectFieldTag.SELECTED_VALUES, selectedValues);
      //TODO: check if the options tag has access to its parent. Access via object ref if possible.
      pageContext.setAttribute(SelectFieldTag.FIELD_STATUS_VARIABLE, this.fieldInstance);
      StringBuffer output = new StringBuffer();
      
      if (fieldInstance.getReadOnly() && selectedValues.size() > 1)
      {
         output.append("<ul>");
      }
      super.doFieldStartTag();
      return TagSupport.EVAL_BODY_INCLUDE;
   }
   
   
   
   
   /* (non-Javadoc)
    * @see net.sf.springlayout.web.layout.taglib.AbstractFieldTag#appendReadOnlyOutput(java.lang.StringBuffer)
    */
   protected void appendReadOnlyOutput(StringBuffer output)
   {
      //For a select tag since doFieldStart is only partially over-ridden we need
      //to protect against the read only value being generated twice in readOnly mode.
      if(!fieldInstance.getReadOnly())
         super.appendReadOnlyOutput(output);
   }

   /**
    */
   /* (non-Javadoc)
    * @see net.sf.springlayout.web.layout.taglib.AbstractFieldTag#appendEditModeOutput(java.lang.StringBuffer)
    */
   protected void appendEditModeOutput(StringBuffer output)
   {
      String confirmedPath = status == null ? this.pathIfNestedNull : status.getExpression();
      output.append("<select name=\"");
      output.append(confirmedPath);
      output.append ("\" id=\"");
      output.append(confirmedPath);
      output.append("\" ");
      if(status == null)
         output.append(" disabled=\"disabled\" ");
      if (multiple.booleanValue())
      {
         output.append(" multiple=\"multiple\" ");
        
         if(this.size != null)
         {
            output.append(" size=\"");
            output.append(this.size);
            output.append("\" ");
         }
      }
      this.appendCommonHtmlAttributes(output);
      this.appendAllApplicableCssClasses(output, false);
      output.append(">");
   }

   /*
    * (non-Javadoc)
    * 
    * @see net.sf.springlayout.web.layout.taglib.LayoutBindTag#doEndTag()
    */
   public int doEndTag() throws JspTagException
   {
      Writer out = this.pageContext.getOut();

      try
      {
         if (fieldInstance.getReadOnly() && selectedValues.size() > 1)
         {
            out.write("</ul>");
         }
         else if(! fieldInstance.getReadOnly())
         {
            out.write("</select>");
            if(multiple.booleanValue())
            {
               out.write("<input type=\"hidden\" name=\"_" + status.getExpression() + "\"/>");
            }
         }
      }
      catch (IOException e)
      {
         throw new JspTagException(e.getMessage());
      }

      pageContext.removeAttribute(SelectFieldTag.SELECTED_VALUES);
      pageContext.removeAttribute(SelectFieldTag.FIELD_STATUS_VARIABLE);

      return super.doEndTag();
   }
   
   /* (non-Javadoc)
    * @see net.sf.springlayout.web.layout.taglib.AbstractFieldTag#getBaseCssClass()
    */
   protected String getBaseCssClass()
   {
      if (multiple.booleanValue())
         return "multiSelect";
      else
         return "singleSelect";
   }

}
