/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.springlayout.web.layout.taglib;

import javax.servlet.http.HttpServletRequest;

import net.sf.springlayout.web.controller.AbstractPanelFormController;
import net.sf.springlayout.web.util.WebConstants;

import org.springframework.validation.BindException;
import org.springframework.validation.Errors;
import org.springframework.web.bind.ServletRequestDataBinder;
import org.springframework.web.context.WebApplicationContext;
import org.springframework.web.servlet.tags.RequestContextAwareTag;


/**
 * Used to swap the command object in the request with that supplied by the <code>getCommandObject</code>
 * method of the supplied controller.  Written specifically to swap the command object when combining many pages 
 * from a MultiPanelFormController into one (Ie, print all panels) when the command object is of different type for one 
 * or more of the controllers for each panel.  Use inline within the page to swap the command object as the page renders.
 * @author rob monie
 *
 */
public class SwapCommandObjectTag extends RequestContextAwareTag
{

   private static final long serialVersionUID = -6764020361891218141L;
   private String controllerBeanName;
   
   /**
    * Sets the name of the controller bean that should return the command object for use in the jsp.
    * @param controllerBeanName
    */
   public void setControllerBeanName(String controllerBeanName)
   {
      this.controllerBeanName = controllerBeanName;
   }


   /* (non-Javadoc)
    * @see org.springframework.web.servlet.tags.RequestContextAwareTag#doStartTagInternal()
    */
   protected int doStartTagInternal() throws Exception
   {

      WebApplicationContext ctx = this.getRequestContext().getWebApplicationContext();
      HttpServletRequest request = (HttpServletRequest) pageContext.getRequest();
      
      AbstractPanelFormController controller = (AbstractPanelFormController) ctx.getBean(this.controllerBeanName);
      Object newCommandObject = null;
      //String oldCommandName = (String) request.getAttribute(WebConstants.COMMAND_NAME);
       if(controller != null)
       {
          request.setAttribute(WebConstants.COMMAND_NAME, controller.getCommandName());
          newCommandObject = controller.getCommandObject(request);
          request.setAttribute(controller.getCommandName(), newCommandObject);
          //Errors oldErrors = this.getRequestContext().getErrors(oldCommandName);
         
          
         ServletRequestDataBinder binder = new ServletRequestDataBinder(newCommandObject, controller.getCommandName());
         controller.initBinder(request, binder);
         
         Errors newErrors = binder.getErrors();
         //newErrors.addAllErrors(oldErrors);
         request.setAttribute(BindException.ERROR_KEY_PREFIX + controller.getCommandName(), newErrors);

       }
       
       return SKIP_BODY;
   }
   

}
