/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.springlayout.web.layout.taglib;

import javax.servlet.http.HttpServletRequest;

import net.sf.springlayout.web.layout.FieldDefinition;
import net.sf.springlayout.web.util.HtmlUtils;

import org.springframework.util.StringUtils;


/**
 * @author Adam Boas
 * Created on 23/04/2006
 */
public class TextAreaFieldTag extends AbstractHtmlInputAttributesTag
{
   private static final long serialVersionUID = 2697106904423979598L;
   
   /**
    * The name of the '<code>maxlength</code>' attribute.
    */
   public static final String MAXLENGTH_ATTRIBUTE = "maxlength";

   /**
    * The name of the '<code>alt</code>' attribute.
    */
   public static final String ALT_ATTRIBUTE = "alt";

   /**
    * The name of the '<code>readonly</code>' attribute.
    */
   public static final String READONLY_ATTRIBUTE = "readonly";
   
   /**
     * The name of the '<code>rows</code>' attribute.
     */
    public static final String ROWS_ATTRIBUTE = "rows";

    /**
     * The name of the '<code>cols</code>' attribute.
     */
    public static final String COLS_ATTRIBUTE = "cols";

    /**
     * The name of the '<code>onselect</code>' attribute.
     */
    public static final String ONSELECT_ATTRIBUTE = "onselect";


    /**
     * The value of the '<code>rows</code>' attribute.
     */
    private String rows;

    /**
     * The value of the '<code>cols</code>' attribute.
     */
    private String cols;

    /**
     * The value of the '<code>onselect</code>' attribute.
     */
    private String onselect;
    
    /**
     * The value of the '<code>maxlength</code>' attribute.
     */
    private String maxlength;

    /**
     * The value of the '<code>alt</code>' attribute.
     */
    private String alt;

    /**
     * The value of the '<code>readonly</code>' attribute.
     */
    private String readonly;

   /**
    *Sets the alt for this TextAreaFieldTag.
    * @param alt Sets the alt for this TextAreaFieldTag.
    */
   public void setAlt(String alt)
   {
      this.alt = alt;
   }

   /**
    *Sets the cols for this TextAreaFieldTag.
    * @param cols Sets the cols for this TextAreaFieldTag.
    */
   public void setCols(String cols)
   {
      this.cols = cols;
   }

   /**
    *Sets the maxlength for this TextAreaFieldTag.
    * @param maxlength Sets the maxlength for this TextAreaFieldTag.
    */
   public void setMaxlength(String maxlength)
   {
      this.maxlength = maxlength;
   }

   /**
    *Sets the onselect for this TextAreaFieldTag.
    * @param onselect Sets the onselect for this TextAreaFieldTag.
    */
   public void setOnselect(String onselect)
   {
      this.onselect = onselect;
   }

   /**
    *Sets the readonly for this TextAreaFieldTag.
    * @param readonly Sets the readonly for this TextAreaFieldTag.
    */
   public void setReadonly(String readonly)
   {
      this.readonly = readonly;
   }

   /**
    *Sets the rows for this TextAreaFieldTag.
    * @param rows Sets the rows for this TextAreaFieldTag.
    */
   public void setRows(String rows)
   {
      this.rows = rows;
   }
   
   /* (non-Javadoc)
    * @see net.sf.springlayout.web.layout.taglib.AbstractFieldTag#appendEditModeOutput(java.lang.StringBuffer)
    */
   protected void  appendEditModeOutput(StringBuffer output)
   {
      String confirmedPath = status == null ? this.pathIfNestedNull : status.getExpression();
      String confirmedValue = status == null ? "" : status.getDisplayValue();
      output.append("<textarea name=\"");
      output.append(confirmedPath);
      output.append("\" id=\"");
      output.append(confirmedPath);
      output.append("\" ");
      if(status == null)
         output.append(" disabled=\"disabled\" ");
      this.appendCommonHtmlAttributes(output);
      this.appendTextAreaAttributes(output);
      this.appendAllApplicableCssClasses(output, false);
      output.append(">");
      output.append(confirmedValue);
      output.append("</textarea>");
      String confirmedMaxLength = this.getMaxLength();
      if(StringUtils.hasText(confirmedMaxLength))
      {
         output.append("<script type=\"text/javascript\">\n");
         output.append("addEvent($('");
         output.append(confirmedPath);
         output.append("'), 'keyup', function(){limitLength(this,");
         output.append(confirmedMaxLength);
         output.append(");});\n");
         output.append("</script>\n");
      }
   }
   
   /* (non-Javadoc)
    * @see net.sf.springlayout.web.layout.taglib.AbstractFieldTag#appendReadOnlyOutput(java.lang.StringBuffer)
    */   
    protected void appendReadOnlyOutput(StringBuffer output)
   {
      if(status != null && StringUtils.hasText(status.getDisplayValue()))
      {
         output.append("<div name=\"");
         output.append(status.getExpression());
         output.append("\" id=\"");
         output.append(status.getExpression());
         output.append("\" class=\"textarea");
         output.append(super.getCssClass() == null ? "" : " " + super.getCssClass());
         output.append("\">");
          output.append(HtmlUtils.newlineToBr(status.getDisplayValue()));
           output.append("</div>");
      }
      else if (this.emptyDisplayString != null)
         output.append(this.emptyDisplayString);
   }
   
   /**
    * Appends the HTML Attributes specific to an input tag to the StringBuffer
    * provided.
    * @param attributeBuffer the StringBuffer to append the HTML Attributes to.
    */
   protected void appendTextAreaAttributes(StringBuffer attributeBuffer)
   {
      if(StringUtils.hasText(this.alt))
         this.appendAttribute(attributeBuffer, ALT_ATTRIBUTE, this.alt);
      if(StringUtils.hasText(this.readonly))
         this.appendAttribute(attributeBuffer, READONLY_ATTRIBUTE, this.readonly);
      if(StringUtils.hasText(this.onselect))
         this.appendAttribute(attributeBuffer, ONSELECT_ATTRIBUTE, this.onselect);
      if(StringUtils.hasText(this.cols))
         this.appendAttribute(attributeBuffer, COLS_ATTRIBUTE, this.cols);
      if(StringUtils.hasText(this.rows))
         this.appendAttribute(attributeBuffer, ROWS_ATTRIBUTE, this.rows);
      
      String confirmedMaxLength = this.getMaxLength();
      if(StringUtils.hasText(confirmedMaxLength))
         this.appendAttribute(attributeBuffer, MAXLENGTH_ATTRIBUTE, confirmedMaxLength);
   }
   
   /**
    * Convenience method to retrieve the correct MaxLength for this tag. Allows 
    * the MaxLength to be specified in the fieldDefinition or to be set or 
    * over-ridden by the tag.
    * @return the maxLength for this Tag.
    */
   private String getMaxLength()
   {
      if(StringUtils.hasText(this.maxlength))
         return this.maxlength;
      
      HttpServletRequest request = (HttpServletRequest) this.pageContext.getRequest();
      FieldDefinition fieldDefinition = getFieldDefinition(request);
      int definitionMaxLength = fieldDefinition.getMaxLength();
      if(definitionMaxLength != -1)
         return Integer.toString(definitionMaxLength);
      
      return null;
   }

   /* (non-Javadoc)
    * @see net.sf.springlayout.web.layout.taglib.AbstractFieldTag#getBaseCssClass()
    */
   protected String getBaseCssClass()
   {
      return "textarea";
   }
}
