/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.springlayout.web.layout.taglib.renderer;

import java.io.IOException;
import java.io.Writer;

import javax.servlet.http.HttpServletRequest;

import net.sf.springlayout.web.layout.PanelForm;
import net.sf.springlayout.web.layout.PanelFormGroup;
import net.sf.springlayout.web.security.PageAccessHolder;
import net.sf.springlayout.web.security.PageAccessManager;

import org.springframework.context.ApplicationContext;
import org.springframework.validation.Errors;
import org.springframework.web.bind.ServletRequestBindingException;
import org.springframework.web.servlet.support.RequestContextUtils;


/**
 * Default panel footer implementation.  Provides next and back buttons for navigation through the panels in edit mode.  
 * Also Skips over disabled panels.
 * @author Rob Monie
 *
 */
public class DefaultPanelFooterRenderer implements PanelFooterRenderer
{

   public void renderFooter(HttpServletRequest request, PanelFormGroup panelFormGroup, PanelForm currentPanel,
         Errors errors, Writer writer) throws IOException, ServletRequestBindingException
   {

      PageAccessHolder pageAccessHolder = PageAccessManager.getPageAccessHolder();
      ApplicationContext ctx = RequestContextUtils.getWebApplicationContext(request);
      writer.write("<div class=\"panelFooter\">");

      int backIndex = currentPanel.getIndex() - 1;
      int nextIndex = currentPanel.getIndex() + 1;
      
      while (backIndex >= 0)
      {
         PanelForm backPanel = (PanelForm) panelFormGroup.getPanelForms().get(backIndex);
         if (!backPanel.isDisabled(request))
         {
            break;
         }
         backIndex--;
      }
      
      while (nextIndex < panelFormGroup.getPanelForms().size())
      {
         PanelForm nextPanel = (PanelForm) panelFormGroup.getPanelForms().get(nextIndex);
         if (! nextPanel.isDisabled(request))
         {
            break;
         }
         nextIndex++;
      }
      
      
      if (pageAccessHolder.isEditMode())
      {
         if (backIndex >= 0)
         {
            writer.write("<button id=\"panelBackButton\" ");
            writer.write(" onclick=\"changePanel('" + currentPanel.getFormName() + "','" + String.valueOf(backIndex) + "');\" >");
            writer.write(ctx.getMessage("panelFooter.backButton", new Object[] {}, request.getLocale()) + "</button>");
         }
         if (nextIndex < panelFormGroup.getPanelForms().size())
         {
            writer.write("<button id=\"panelNextButton\"");
            writer.write(" onclick=\"changePanel('" + currentPanel.getFormName() + "','" + String.valueOf(nextIndex) + "');\">");
            writer.write(ctx.getMessage("panelFooter.nextButton", new Object[] {}, request.getLocale()) + "</button>");
         }
      }

      writer.write("</div>");
   }

}
