/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.springlayout.web.security;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.util.Assert;

/**
 * Provides static methods for setting and accessing
 * <code>PageAccessHolder</code>. Uses threadLocal to store the
 * <code>PageAccessHolder</code> instead of the request so these can be
 * accessed from anywhere independently of the request.
 * 
 * @author monier
 * 
 */
public abstract class PageAccessManager
{

   private static Log log = LogFactory.getLog(PageAccessManager.class);
   private static ThreadLocal pageAccessHolderThreadLocal = new ThreadLocal();

   /**
    * Gets the current pageAccessHolder from ThreadLocal
    * 
    * @return pageAccessHolder
    */
   public static PageAccessHolder getPageAccessHolder()
   {

      PageAccessHolder pageAccessHolder = (PageAccessHolder) pageAccessHolderThreadLocal.get();
      if(pageAccessHolder == null)
      {
         PageAccessManager.setPageAccessHolder(new PageAccessHolder());
         pageAccessHolder = (PageAccessHolder) pageAccessHolderThreadLocal.get();
      }
      
      return pageAccessHolder;

   }

   /**
    * Sets the pageAccessHolder as a threadLocal variable that can be queried
    * via <code>PageAccessManager.getPageAccessHolder</code>
    * 
    * @param pageAccessHolder
    */
   public static void setPageAccessHolder(PageAccessHolder pageAccessHolder)
   {
      Assert.notNull(pageAccessHolder,
            "Only non-null PageAccessHolder instances are permitted");
      pageAccessHolderThreadLocal.set(pageAccessHolder);
   }

}
