/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.springlayout.web.security;

import javax.servlet.http.HttpServletRequest;

/**
 * Responsible for determining a user's access to the current resource / page, firstly in terms of edit / read / no access 
 * and secondly in terms of access to individual functions for the page.  For example for a given page or request, 
 * it may be necessary to determine the display of an 'edit' or 'save' button based on the current user's roles and various 
 * other factors such as the status of the current command object.
 * 
 * Implementing classes should generally not implement this interface directly but rather extend the 
 * AbstractPageAccessResolver class as it handles storage and retrieval of function data in the request and provides 
 * helper methods for accessing the function permission map..
 * 
 * @author rob monie
 *
 */
public interface PageAccessResolver
{

   /**
    * Should initialise all page function access requirements such as read edit mode access and access to functions for this request.
    * @param request
    * @param object
    */
   public void initialisePageAccess(HttpServletRequest request, Object object);
   
   
   /**
    * Gets a page function state for a given function name for the current request.
    * @param functionName
    * @return
    */
   public PageFunctionState getPageFunctionState(String functionName);
   

   /**
    * 
    * @return should this pageAccessResolver be run on form submission
    */
   public boolean isRunOnFormSubmission();
   
}
