/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.springlayout.web.security;


/**
 * Typesafe Enumeration for representing Page Function States.  
 * For example a save button may be in a state opf enabled, disabled or hidden.
 * 
 * @author Rob Monie
 * 
*/
public class PageFunctionState implements Comparable
{

   /**
    * page function is not visible / available
    */
   public static final PageFunctionState HIDDEN = new PageFunctionState(0);
   
   /**
    * Page function is visible but disabled
    */
   public static final PageFunctionState DISABLED = new PageFunctionState(1);
   
   /**
    * Page function is enabled
    */
   public static final PageFunctionState ENABLED = new PageFunctionState(2);
   
   private int pageFunctionState;
   
   /**
    * Default private contructor
    * @param pageFunctionState
    */
   private PageFunctionState(int pageFunctionState)
   {
      this.pageFunctionState = pageFunctionState;
   }
   
   /* (non-Javadoc)
    * @see java.lang.Object#toString()
    */
   public String toString()
   {
      if(pageFunctionState == ENABLED.pageFunctionState) 
      {
         return "ENABLED";
      }
      else if(pageFunctionState == DISABLED.pageFunctionState) 
      {
         return "DISABLED";
      }
      else if(pageFunctionState == HIDDEN.pageFunctionState) 
      {
         return "HIDDEN";
      }
      
      
      return String.valueOf(pageFunctionState);
   }

   /* (non-Javadoc)
    * @see java.lang.Comparable#compareTo(java.lang.Object)
    */
   public int compareTo(Object other)
   {
      int otherPageFunctionState = ((PageFunctionState) other).pageFunctionState;

      return this.pageFunctionState - otherPageFunctionState;
   }
   

   
}
