/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.springlayout.web.security;

import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.Set;

/**
 * A wrapper for <code>java.util.Map</code> to enforce storage and retrieval of objects of type PageFunctionState
 * @author Rob Monie
 *
 */
public class PageFunctionStateMap
{
   
   private Map target;

   
   public PageFunctionStateMap()
   {
      this.target  = new HashMap();
   }

   /** gets a page function state by key
    * @see java.util.Map#get(java.lang.Object)
    */
   public PageFunctionState get(Object key)
   {
      return (PageFunctionState) this.target.get(key);
   }

   /**
    * Adds a page function state by key
    * @param key
    * @param pageFunctionState
    */
   public void put(Object key, PageFunctionState pageFunctionState)
   {
      this.target.put(key, pageFunctionState);
   }
   

   /**
    * Removes and object by key
    * @param key
    */
   public void remove(Object key)
   {
      this.target.remove(key);
   }
   

   /**
    * Clears the target map
    */
   public void clear()
   {
      this.target.clear();
   }
   
   /**
    * 
    * @return the number of elements in the map
    */
   public int size()
   {
      return target.size();
   }
   
   /**
    * Gets the entrySet for the underlying map
    * @return
    */
   public Set entrySet()
   {
      return this.target.entrySet();
   }
   
   /**
    * Gets the keySet for the underlying map
    * @return
    */
   public Set keySet()
   {
      return this.target.keySet();
   }

   /* (non-Javadoc)
    * @see java.lang.Object#toString()
    */
   public String toString()
   {
      StringBuffer buffy = new StringBuffer();
      buffy.append("PageFunctionStateMap[ ");
      for(Iterator it = this.target.keySet().iterator(); it.hasNext(); )
      {
         String key = (String)it.next();
         buffy.append("State for: ");
         buffy.append(key);
         buffy.append("=");
         buffy.append(this.target.get(key));
         buffy.append(", ");
      }
      buffy.append(" ]");
      return buffy.toString();
   }

}
