/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.springlayout.web.security.taglib;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.tagext.TagSupport;

import net.sf.springlayout.web.security.PageAccessManager;
import net.sf.springlayout.web.security.PageFunctionState;


/**
 * Tag to determine if a user has the specified access to a particular page function.
 */
public final class HasPageFunctionTag extends TagSupport
{
   private static final long serialVersionUID = 8723436265463875824L;
   
   private String functionName;
   private String state;
   
   /**
    * Sets the functionName for this HasPageFunctionTag.
    * @param functionName Sets the functionName for this HasPageFunctionTag.
    */
   public void setFunctionName(String functionName) 
   {
      this.functionName = functionName;
   }

   /**
    * Sets the state for this HasPageFunctionTag.  Possible values are:
    * 
    * <ul>
    * <li>enabled</li>
    * <li>disabled</li>
    * <li>hidden</li>
    * </ul>
    * 
    * @param state Sets the state for this HasPageFunctionTag.
    */
   public void setState(String state) 
   {
      this.state = state;
   }

   public int doStartTag() throws JspException
   {

      PageFunctionState functionState = PageAccessManager.getPageAccessHolder()
                              .getPageFunctionState(functionName);
       
      if(PageFunctionState.ENABLED.equals(functionState) && "enabled".equals(state.toLowerCase()))   
         return EVAL_BODY_INCLUDE;

      else if(PageFunctionState.DISABLED.equals(functionState) && "disabled".equals(state.toLowerCase()))   
         return EVAL_BODY_INCLUDE;

      else if(PageFunctionState.HIDDEN.equals(functionState) && "hidden".equals(state.toLowerCase()))   
         return EVAL_BODY_INCLUDE;
      
      else return SKIP_BODY;

   }
   
}
