/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.springlayout.web.util;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * Utility for managing paths for fields.
 * 
 * @author Adam Boas
 * Created on 25/05/2006
 */
public class FieldPathUtils
{
   public static String correctDependentPath(String indexedPath, String unindexedPath)
   {
      Pattern pattern = Pattern.compile("\\[\\w*\\]");
      Matcher currentPathMatcher = pattern.matcher(unindexedPath);
      Matcher oldPathMatcher = pattern.matcher(indexedPath);
      if (currentPathMatcher.find() || !oldPathMatcher.find())
         return unindexedPath;

      // now we do some serious path mangling...
      String[] splitPath = unindexedPath.split("\\.");
      String[] splitFieldPath = indexedPath.split("\\.");
      StringBuffer modifiedPath = new StringBuffer();
      for (int ii = 0; ii < splitFieldPath.length && ii < splitPath.length; ii++)
      {
         pattern = Pattern.compile(splitPath[ii] + "\\[\\w*\\]");
         Matcher matcher = pattern.matcher(splitFieldPath[ii]);
         if (matcher.find())
            modifiedPath.append(splitFieldPath[ii]);
         else
            modifiedPath.append(splitPath[ii]);
         modifiedPath.append(".");
      }
      modifiedPath.deleteCharAt(modifiedPath.length() - 1);
      return modifiedPath.toString();
   }

}
