/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.springlayout.web.util;

import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.web.bind.RequestUtils;
import org.springframework.web.bind.ServletRequestBindingException;


/**
 * Supports Spring's RequestUtils providing variations to the standard
 * requestUtils Methods
 * 
 * @author Rob Monie
 * 
 */
public class RequestUtilSupport
{

   private static Log log = LogFactory.getLog(RequestUtilSupport.class);

   /**
    * Gets an Integer parameter from the request with the option of preventing
    * an empty value for the parameter throwing an exception but returning null
    * instead.
    * 
    * @param request
    * @param name
    * @param allowEmpty
    * @return integer value
    */
   public static Integer getIntegerParameter(HttpServletRequest request, String name, boolean allowEmpty)
         throws ServletRequestBindingException
   {

      try
      {
         return RequestUtils.getIntParameter(request, name);
      }
      catch (ServletRequestBindingException e)
      {
         if (allowEmpty)
            if (request.getParameter(name).equals(""))
            {
               return null;
            }
            else
            {
               throw e;
            }
         else
         {
            throw e;
         }
      }
   }
   
   /**
    * Gets a Long parameter from the request with the option of preventing
    * an empty value for the parameter throwing an exception but returning null
    * instead.
    * 
    * @param request
    * @param name
    * @param allowEmpty
    * @return long value
    */
   public static Long getLongParameter(HttpServletRequest request, String name, boolean allowEmpty)
         throws ServletRequestBindingException
   {

      try
      {
         return RequestUtils.getLongParameter(request, name);
      }
      catch (ServletRequestBindingException e)
      {
         if (allowEmpty)
            if (request.getParameter(name).equals(""))
            {
               return null;
            }
            else
            {
               throw e;
            }
         else
         {
            throw e;
         }
      }
   }

   
   /**
    * Converts a statemap for use in urls by removing params that should not be reflected in the url.
    * 
    * 
    * @param map
    * @return
    */
   public static Map getStateMapForUrl(Map stateMap)
   {
      Map urlArgsMap = new HashMap();
      urlArgsMap.putAll(stateMap);
      urlArgsMap.remove(WebConstants.COMMAND_DIRTY);
      urlArgsMap.remove(WebConstants.VALIDATE_MODE_PARAM);
      return urlArgsMap;
   }
}
