/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.springlayout.web.util;



/**
 * General constant values used for general web related purposes 
 * 
 * @author Rob Monie
 * 
*/

public class WebConstants
{

   //   ==============REQUEST ATTRIBUTES==================
   /**
    * Name of request attribute holding messages for display in UI
    */
   public static final String MESSAGES = "messages";
   
   /**
    * Name of request attribute holding errors for display in UI
    */
   public static final String ERRORS = "errors";
   
   
   /**
    * Name of the pageContext attribute holding the current form object
    */
   public static final String CURRENT_FORM = "currentForm";
   
   /**
    * Name of the pageContext attribute holding the current field object status
    */
   public static final String CURRENT_FIELD_STATUS = "currentFieldStatus";
   
   /**
    * name of the attribute holding the currentUser in the request
    */
   public static final String CURRENT_USER = "currentUser";
   
   /**
    * Name of the attribute holding the command object
    */
   public static final String COMMAND_NAME = "commandName";
   
   /**
    * Name of the attribute holding the current module name
    */
   public static final String CURRENT_MODULE = "currentModule";
   
   /**
    * Name of the request parameter used to determine whether currently validating or not.
    */
   public static final String CURRENTLY_VALIDATING = "currentlyValidating";
   
   
   //   ==============REQUEST PARAMETERS==================
   /**
    * Name of the request parameter used to determine edit mode.  This should not be used directly
    * by application code. The PAGE_ACCESS_HOLDER should be used instead.
    */
   public static final String EDIT_MODE_PARAM = "e";
  
   /**
    * Name of the request parameter used to determine validation mode.
    */
   public static final String VALIDATE_MODE_PARAM = "validateMode";
   

   
   /**
    * Default edit mode if not set by controller  
    */
   public static final String EDIT_MODE_DEFAULT = "0";
   
   /**
    * Name of the request parameter used to set the validation mode if it has not 
    * been set explicitly in the Request parameters.
    */
   public static final String VALIDATION_MODE_DEFAULT = "0";
   
   /**
    * Name of the request parameter used to hold the bean wrapper for the current command.
    */
   public static final String BEAN_WRAPPER = "beanWrapper";
   
   /**
    * Name of the request parameter used to determine a record id.
    */
   public static final String RECORD_ID_PARAM = "id";

   /**
    *Name of the map which contains the current query details
    */
   public static final String STATE_MAP = "stateMap";

   /**
    * The name of the field used to hold the position of the screen to be returned to after a post back.
    */
   public static final String SCREEN_POSITION_PARAM = "screenPosition";

   /**
    * Name of the parameter key used to maintain if the current command object has been altered
    * since it was loaded.
    */
   public static final String COMMAND_DIRTY = "commandDirty";
   
   /**
    * Name of the paramter key used to determine if the user has selected to save the record
    * based on the confirmation from a dirty check.
    */
   public static final String DO_SAVE = "doSave";

   /**
    * Name of the parameter used to determine whether to display as printable.
    */
   public static final String PRINT_PARAMETER = "print";

   public static final Object DEFAULT_FIELD_NAME = "DEFAULT_FIELD";
   
   /**
    * Request attribute to indicate whether the loading message should be shown on the current page.
    */
   public static final String SHOW_LOADING_MESSAGE = "showLoadingMessage";
   
   /**
    * Request attribute to hold the target panel when changing panels on a multi-page form
    */
   public static final String TARGET_PANEL_PARAM = "targetPanel";
   
   /**
    * Page Context attribute holding the currently rendering form tag
    */
   public static final String LAYOUT_FORM_TAG = "layoutFormTag";

   /**
    * Page context attribute for building up js to be rendered at the end of a form
    */
   public static final String FORM_END_JAVASCRIPT = "formEndJS";
}
