/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.springlayout.web.validator;

import javax.servlet.http.HttpServletRequest;

import org.apache.commons.lang.StringUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.beans.factory.InitializingBean;
import org.springframework.validation.Errors;

/**
 * Provides type validation for decimals with the ability to specify a maxuimum number of decimal places
 * 
 * @author Rob Monie
 * 
 */
public class DecimalValidator extends AbstractValidationRule
{
   private static Log log = LogFactory.getLog(DecimalValidator.class);
   private int maxDecimalPlaces;
   
   public DecimalValidator()
   {
   }

   
   /**
    * @return the maxDecimalPlaces
    */
   public int getMaxDecimalPlaces()
   {
      return maxDecimalPlaces;
   }


   /**
    * Specify the max number of decimal places to test for.  Default is 0
    * @param maxDecimalPlaces the maxDecimalPlaces to set
    */
   public void setMaxDecimalPlaces(int maxDecimalPlaces)
   {
      this.maxDecimalPlaces = maxDecimalPlaces;
   }



   /**
    * This method is not implemented as valdiating of types is taken care of
    * through the binding process. If the value of this field is not of type
    * Integer then it will never get here.
    * 
    * @see net.sf.springlayout.web.validator.ValidationRule#validate(javax.servlet.http.HttpServletRequest,
    *      java.lang.Object, org.springframework.validation.Errors,
    *      java.lang.String)
    */
   public void validate(HttpServletRequest request, Object obj, Errors errors, String fieldKey)
   {
      if (! isValid(obj, fieldKey))
      {
         errors.rejectValue(fieldKey, "errors.tooManyDecimalPlaces");
      }
   }

   /**
    * As with the validate method, if it gets this far then the field value must be valid.
    * 
    * @see net.sf.springlayout.web.validator.ValidationRule#isValid(java.lang.Object,
    *      java.lang.String)
    */
   public boolean isValid(Object obj, String fieldKey)
   {
      Object fieldValue = this.getFieldValue(obj, fieldKey);
      
      if(fieldValue != null )
      {  
         String decimalString = StringUtils.substringAfter(fieldValue.toString(), ".");
         if(decimalString.length() > this.maxDecimalPlaces)
         {
            return false;
         }
         else
            return true;
      }
      else
         return true;
   }

   /*
    * (non-Javadoc)
    * 
    * @see net.sf.springlayout.web.validator.ValidationRule#getJavascript()
    */
   public String getJavascript()
   {
      StringBuffer script = new StringBuffer();
      script.append("validateDecimal(field," + this.maxDecimalPlaces + ",");
      script.append("alerts)");
      return script.toString();
   }


}
