/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.springlayout.web.validator;

import javax.mail.internet.AddressException;
import javax.mail.internet.InternetAddress;
import javax.servlet.http.HttpServletRequest;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.validation.Errors;

/**
 * Email Validation Rule. Ensures that a field meets minimum criteria for a valid email address.
 * 
 * @author Rob Monie, Adam Boas
 *
 */
public class EmailValidator extends AbstractValidationRule
{
   private static Log log = LogFactory.getLog(EmailValidator.class);
   
   /**
    * Validates  the field specified in the field definition against the object 
    * passed to ensure it's a valid email address.  Adds to errors object of validation fails
    * 
    * @param request the current servlet request
    * @param obj the object to validate
    * @param errors the current errors
    * @param fieldKey the path to the field in the object to validate
    * @see net.sf.springlayout.web.validator.ValidationRule#validate(javax.servlet.http.HttpServletRequest, java.lang.Object, org.springframework.validation.Errors, net.sf.springlayout.web.panel.IFieldDefinition)
    */
   public void validate(HttpServletRequest request, Object obj, Errors errors,
         String fieldKey)
   {
      if (! isValid(obj, fieldKey))
      {
         errors.rejectValue(fieldKey, "errors.invalidEmailAddress");
      }
   }


   public boolean isValid(Object obj, String fieldKey)
   {
     
      Object fieldValue = this.getFieldValue(obj, fieldKey);
      
      if(fieldValue != null )
      {  
          try
         {
            InternetAddress emailAddress = new InternetAddress(fieldValue.toString());
            emailAddress.validate();
            log.debug("Email address '" + emailAddress.getAddress() + "' passed validation");
         }
         catch (AddressException e)
         {
            log.debug("Email address '" + fieldValue.toString() + "' failed validation");
            return false;
         }
      }
      return true;
   }
   
   
   /* (non-Javadoc)
    * @see net.sf.springlayout.web.validator.ValidationRule#getJavascript(java.lang.String, java.util.List)
    */
   public String getJavascript()
   {
      return "validateEmail(field,alerts)";
   }


}
