/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.springlayout.web.validator;

import javax.servlet.http.HttpServletRequest;

import org.springframework.validation.Errors;

/**
 * @auther Adam Boas
 * Created on Jan 19, 2007
 */
public class MaxLengthValidator extends AbstractValidationRule
{

   private int maxLength;
   
   /* (non-Javadoc)
    * @see net.sf.springlayout.web.validator.ValidationRule#getJavascript()
    */
   public String getJavascript()
   {
      return "validateMaxLength(field," + maxLength + ",alerts)";
   }

   /* (non-Javadoc)
    * @see net.sf.springlayout.web.validator.ValidationRule#validate(javax.servlet.http.HttpServletRequest, java.lang.Object, org.springframework.validation.Errors, java.lang.String)
    */
   public void validate(HttpServletRequest request, Object obj, Errors errors,
         String fieldKey)
   {
      if (! isValid(obj, fieldKey))
      {
         errors.rejectValue(fieldKey, "errors.invalidLength");
      }

   }

   public boolean isValid(Object obj, String fieldKey)
   {
      
      Object fieldValue = this.getFieldValue(obj, fieldKey);
      
      if(fieldValue != null && fieldValue.toString().length() > maxLength)
      {
         return false;
      }
      return true;
   }

   /**
    * Sets the maxLength for this MaxLengthValidator.
    * @param maxLength Sets the maxLength for this MaxLengthValidator.
    */
   public void setMaxLength(int maxLength)
   {
      this.maxLength = maxLength;
   }

   public int getMaxLength()
   {
      return maxLength;
   }


   
}
