/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.springlayout.web.validator;

import javax.servlet.http.HttpServletRequest;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.validation.Errors;

/**
 * Provides number  validation against the supplied Minimum value.
 * 
 * @author Adam Boas
 *
 */
public class MinValueValidator extends AbstractValidationRule
{
   private static Log log = LogFactory.getLog(MinValueValidator.class);

   private double minValue;

   public MinValueValidator() { }

   /**
    * Construct Validator with minvalue
    * @param minValue
    * @throws NullPointerException
    */
   public MinValueValidator(double minValue)
   {
      this.minValue = minValue;
   }

   /**
    * Sets the minValue for this MinValueValidator.
    * @param minValue Sets the minValue for this IntegerNumberRangeValidator.
    */
   public void setMinValue(double minValue)
   {
      this.minValue = minValue;
   }

   /**
    * Validates object against min value.
    * 
    * @see net.sf.springlayout.web.validator.ValidationRule#validate(javax.servlet.http.HttpServletRequest,
    *      java.lang.Object, org.springframework.validation.Errors,
    *      java.lang.String)
    */
   public void validate(HttpServletRequest request, Object obj, Errors errors,
         String fieldKey)
   {

      if(!this.isValid(obj, fieldKey))
      {
         errors.rejectValue(fieldKey, 
                            "errors.maxValueValidation", 
                            new Object[] { "" + minValue }, 
                            "errors.minValueValidation");
      }
   }


   /* (non-Javadoc)
    * @see net.sf.springlayout.web.validator.ValidationRule#getJavascript()
    */
   public String getJavascript()
   {
      StringBuffer script = new StringBuffer();
      script.append("validateMinValue(field,'");
      script.append(this.minValue);
      script.append("',alerts)");
      return script.toString();
   }

   /* (non-Javadoc)
    * @see net.sf.springlayout.web.validator.ValidationRule#isValid(java.lang.Object, java.lang.String)
    */
   public boolean isValid(Object obj, String fieldKey)
   {

      Object fieldValue = this.getFieldValue(obj, fieldKey);

      if (fieldValue != null)
      {
         try
         {

            double numValue = Double.parseDouble(fieldValue.toString());

            if (numValue < minValue)
            {
               log.debug("Failed min value validation. Value " + numValue + " is < " + minValue);
               return false;
            }

         }
         catch (NumberFormatException e)
         {
            log.debug("Attempt to validate a non-numeric value");
            return false;
         }

      }
      return true;
   }

}
