/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.springlayout.web.validator;

import javax.servlet.http.HttpServletRequest;

import net.sf.springlayout.web.layout.OnPageFieldInstance;

import org.springframework.validation.Errors;

/**
 * Defines a validation rule for use by fieldDefininitions
 * 
 * @author monier
 *
 */
public interface ValidationRule
{

   /**
    * Validates the command object against this validation rule and adds to the errors if validation fails.
    * 
    * @param request the current HttpServletRequest
    * @param obj the current command object to be validated
    * @param errors the current errors for this request
    * @param fieldKey the path or key to the field in the target object to validate
    */
   public void conditionallyValidate(HttpServletRequest request, Object obj, Errors errors, String fieldKey);

   
   /**
    * Returns if this object is valid according to this validation rule
    * 
    * @param obj
    * @return
    */
   public boolean isValid(Object obj, String fieldKey);
   
   
   /**
    * Retrieves a javascript representation of this validation rule which will be
    * applied to each of the events supplied in eventNames. This function will be 'anded' together with
    * other rules and so should always return boolean and have no semi-colon
    * eg. A == B
    * 
    * The context which surrounds this javascrit must contain the 'field' to execute this 
    * javascript upon. 
    * @param fieldInstance
    * @param command
    * @param formName
    * @return String containing the conditional javascript registration for this validation rule
    * against the event names supplied.
    */
   public String getConditionalJavascript(OnPageFieldInstance fieldInstance, Object command, String formName);

}
