/* Copyright 2005 - 2007 Spring Layout Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.springlayout.web.validator.condition;

import java.io.Serializable;
import java.util.Iterator;
import java.util.List;

import net.sf.springlayout.web.layout.LayoutFormConfigurationException;
import net.sf.springlayout.web.layout.OnPageFieldInstance;

import org.springframework.beans.BeanWrapper;


/**
 * @author Jon, Adam Boas
 *
 */
abstract public class AbstractBooleanCondition implements Serializable, Condition
{
   protected List conditionList;
   protected String operator;

   /**
    * @return Returns the conditionList.
    */
   public List getConditionList()
   {
      return conditionList;
   }

   /**
    * @param conditionList the conditionList to set
    */
   public void setConditionList(List conditionList)
   {
      this.conditionList = conditionList;
   }

   /* (non-Javadoc)
    * @see net.sf.springlayout.web.validator.condition.Condition#evaluate(org.springframework.beans.BeanWrapper)
    */
   abstract public boolean evaluate(String fieldId, BeanWrapper wrappedObject);

   /* (non-Javadoc)
    * @see net.sf.springlayout.web.validator.condition.Condition#getJavascript(net.sf.springlayout.web.layout.FieldDefinition, java.lang.Object)
    */
   public String getJavascript(OnPageFieldInstance instance, Object command, String formName)
   {
      StringBuffer buffer = new StringBuffer("(");
      for (Iterator iter = conditionList.iterator();iter.hasNext();)
      {
         Condition condition = (Condition) iter.next();
         buffer.append(buffer.length() >1 ? " " +operator +" " :  "");
         buffer.append(condition.getJavascript(instance, command, formName));
         
      }
      buffer.append(")");
      return buffer.toString();
      
   }
   
   /* (non-Javadoc)
    * @see net.sf.springlayout.web.validator.condition.Condition#getJavascript(net.sf.springlayout.web.layout.FieldDefinition, java.lang.Object)
    */
   public String getPostProcessingJavascript(OnPageFieldInstance instance, String formName)
   {
      StringBuffer buffer = new StringBuffer();
      for (Iterator iter = conditionList.iterator();iter.hasNext();)
      {
         Condition condition = (Condition) iter.next();
         buffer.append(condition.getPostProcessingJavascript(instance, formName));
         
      }
      return buffer.toString();
      
   }

   /* (non-Javadoc)
    * @see net.sf.springlayout.web.validator.condition.Condition#validate()
    */
   public void afterPropertiesSet()
   {
      StringBuffer errors= new StringBuffer();
      for (Iterator iter = conditionList.iterator();iter.hasNext();)
      {
         Condition condition = (Condition) iter.next();
         try
         {
            condition.afterPropertiesSet();
         }
         catch (LayoutFormConfigurationException e)
         {
            errors.append(errors.length()>0 ? "":",\n");
            errors.append(e.getMessage());
         }
      }
      if (errors.length() > 0)
         throw new LayoutFormConfigurationException(errors.toString());
      
   }

   
}
